# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline/pipeline/v1beta/component_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from pipeline.pipeline.v1beta import common_pb2 as pipeline_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3pipeline/pipeline/v1beta/component_definition.proto\x12\x18pipeline.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a%pipeline/pipeline/v1beta/common.proto\"\xbe\r\n\x13\x43omponentDefinition\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12\x19\n\x05title\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x05title\x12\x30\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x10\x64ocumentationUrl\x12\x17\n\x04icon\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x04icon\x12K\n\x04spec\x18\x07 \x01(\x0b\x32\x32.pipeline.pipeline.v1beta.ComponentDefinition.SpecB\x03\xe0\x41\x03R\x04spec\x12@\n\x04type\x18\x08 \x01(\x0e\x32\'.pipeline.pipeline.v1beta.ComponentTypeB\x03\xe0\x41\x03R\x04type\x12!\n\ttombstone\x18\t \x01(\x08\x42\x03\xe0\x41\x03R\ttombstone\x12\x1b\n\x06public\x18\n \x01(\x08\x42\x03\xe0\x41\x03R\x06public\x12\x1b\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x03\xe0\x41\x03R\x06\x63ustom\x12\x1b\n\x06vendor\x18\x0c \x01(\tB\x03\xe0\x41\x03R\x06vendor\x12I\n\x11vendor_attributes\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x10vendorAttributes\x12\"\n\nsource_url\x18\x0e \x01(\tB\x03\xe0\x41\x03R\tsourceUrl\x12\x1d\n\x07version\x18\x0f \x01(\tB\x03\xe0\x41\x03R\x07version\x12\x42\n\x05tasks\x18\x10 \x03(\x0b\x32\'.pipeline.pipeline.v1beta.ComponentTaskB\x03\xe0\x41\x03R\x05tasks\x12%\n\x0b\x64\x65scription\x18\x11 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x64\n\rrelease_stage\x18\x12 \x01(\x0e\x32:.pipeline.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x03\xe0\x41\x03R\x0creleaseStage\x12\x45\n\x06\x65vents\x18\x13 \x03(\x0b\x32(.pipeline.pipeline.v1beta.ComponentEventB\x03\xe0\x41\x03R\x06\x65vents\x1a\xd0\x04\n\x04Spec\x12U\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x16\x63omponentSpecification\x12\x80\x01\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32J.pipeline.pipeline.v1beta.ComponentDefinition.Spec.DataSpecificationsEntryB\x03\xe0\x41\x03R\x12\x64\x61taSpecifications\x12\x83\x01\n\x14\x65vent_specifications\x18\x06 \x03(\x0b\x32K.pipeline.pipeline.v1beta.ComponentDefinition.Spec.EventSpecificationsEntryB\x03\xe0\x41\x03R\x13\x65ventSpecifications\x1ar\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32+.pipeline.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01\x1at\n\x18\x45ventSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.pipeline.pipeline.v1beta.EventSpecificationR\x05value:\x02\x38\x01\";\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\"\xbc\x01\n\x0cReleaseStage\x12\x1d\n\x19RELEASE_STAGE_UNSPECIFIED\x10\x00\x12\'\n#RELEASE_STAGE_OPEN_FOR_CONTRIBUTION\x10\x01\x12\x1d\n\x19RELEASE_STAGE_COMING_SOON\x10\x02\x12\x17\n\x13RELEASE_STAGE_ALPHA\x10\x03\x12\x16\n\x12RELEASE_STAGE_BETA\x10\x04\x12\x14\n\x10RELEASE_STAGE_GA\x10\x05\"}\n\x11\x44\x61taSpecification\x12\x32\n\x05input\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x05input\x12\x34\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x06output\"\xa7\x02\n\x12\x45ventSpecification\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x41\n\rconfig_schema\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0c\x63onfigSchema\x12\x43\n\x0emessage_schema\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\rmessageSchema\x12G\n\x10message_examples\x18\x05 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0fmessageExamples\"\x8b\x02\n\x1fListComponentDefinitionsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12P\n\x04view\x18\x03 \x01(\x0e\x32\x32.pipeline.pipeline.v1beta.ComponentDefinition.ViewB\x03\xe0\x41\x01H\x01R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x12\x1c\n\x04page\x18\x05 \x01(\x05\x42\x03\xe0\x41\x01H\x03R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_viewB\t\n\x07_filterB\x07\n\x05_pageJ\x04\x08\x02\x10\x03\"\xdc\x01\n ListComponentDefinitionsResponse\x12\x62\n\x15\x63omponent_definitions\x18\x01 \x03(\x0b\x32-.pipeline.pipeline.v1beta.ComponentDefinitionR\x14\x63omponentDefinitions\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04pageJ\x04\x08\x02\x10\x03\x42\x85\x02\n\x1c\x63om.pipeline.pipeline.v1betaB\x18\x43omponentDefinitionProtoP\x01ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\xa2\x02\x03PPX\xaa\x02\x18Pipeline.Pipeline.V1beta\xca\x02\x18Pipeline\\Pipeline\\V1beta\xe2\x02$Pipeline\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x1aPipeline::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline.pipeline.v1beta.component_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.pipeline.pipeline.v1betaB\030ComponentDefinitionProtoP\001ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\242\002\003PPX\252\002\030Pipeline.Pipeline.V1beta\312\002\030Pipeline\\Pipeline\\V1beta\342\002$Pipeline\\Pipeline\\V1beta\\GPBMetadata\352\002\032Pipeline::Pipeline::V1beta'
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION_SPEC.fields_by_name['event_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['event_specifications']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['name']._options = None
  _COMPONENTDEFINITION.fields_by_name['name']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['uid']._options = None
  _COMPONENTDEFINITION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['id']._options = None
  _COMPONENTDEFINITION.fields_by_name['id']._serialized_options = b'\340A\005'
  _COMPONENTDEFINITION.fields_by_name['title']._options = None
  _COMPONENTDEFINITION.fields_by_name['title']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['icon']._options = None
  _COMPONENTDEFINITION.fields_by_name['icon']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['spec']._options = None
  _COMPONENTDEFINITION.fields_by_name['spec']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['type']._options = None
  _COMPONENTDEFINITION.fields_by_name['type']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['tombstone']._options = None
  _COMPONENTDEFINITION.fields_by_name['tombstone']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['public']._options = None
  _COMPONENTDEFINITION.fields_by_name['public']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['custom']._options = None
  _COMPONENTDEFINITION.fields_by_name['custom']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['vendor']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['source_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['source_url']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['version']._options = None
  _COMPONENTDEFINITION.fields_by_name['version']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['tasks']._options = None
  _COMPONENTDEFINITION.fields_by_name['tasks']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['description']._options = None
  _COMPONENTDEFINITION.fields_by_name['description']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['release_stage']._options = None
  _COMPONENTDEFINITION.fields_by_name['release_stage']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['events']._options = None
  _COMPONENTDEFINITION.fields_by_name['events']._serialized_options = b'\340A\003'
  _DATASPECIFICATION.fields_by_name['input']._options = None
  _DATASPECIFICATION.fields_by_name['input']._serialized_options = b'\340A\003'
  _DATASPECIFICATION.fields_by_name['output']._options = None
  _DATASPECIFICATION.fields_by_name['output']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['title']._options = None
  _EVENTSPECIFICATION.fields_by_name['title']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['description']._options = None
  _EVENTSPECIFICATION.fields_by_name['description']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['config_schema']._options = None
  _EVENTSPECIFICATION.fields_by_name['config_schema']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['message_schema']._options = None
  _EVENTSPECIFICATION.fields_by_name['message_schema']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['message_examples']._options = None
  _EVENTSPECIFICATION.fields_by_name['message_examples']._serialized_options = b'\340A\003'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _globals['_COMPONENTDEFINITION']._serialized_start=184
  _globals['_COMPONENTDEFINITION']._serialized_end=1910
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_start=1066
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_end=1658
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_start=1426
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_end=1540
  _globals['_COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY']._serialized_start=1542
  _globals['_COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY']._serialized_end=1658
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_start=1660
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_end=1719
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_start=1722
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_end=1910
  _globals['_DATASPECIFICATION']._serialized_start=1912
  _globals['_DATASPECIFICATION']._serialized_end=2037
  _globals['_EVENTSPECIFICATION']._serialized_start=2040
  _globals['_EVENTSPECIFICATION']._serialized_end=2335
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_start=2338
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_end=2605
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_start=2608
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_end=2828
# @@protoc_insertion_point(module_scope)
