# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/agent_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent.agent.v1alpha import agent_pb2 as agent_dot_agent_dot_v1alpha_dot_agent__pb2
from agent.agent.v1alpha import chat_pb2 as agent_dot_agent_dot_v1alpha_dot_chat__pb2
from agent.agent.v1alpha import table_pb2 as agent_dot_agent_dot_v1alpha_dot_table__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.agent/agent/v1alpha/agent_public_service.proto\x12\x13\x61gent.agent.v1alpha\x1a\x1f\x61gent/agent/v1alpha/agent.proto\x1a\x1e\x61gent/agent/v1alpha/chat.proto\x1a\x1f\x61gent/agent/v1alpha/table.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xee?\n\x12\x41gentPublicService\x12\x9d\x01\n\x08Liveness\x12$.agent.agent.v1alpha.LivenessRequest\x1a%.agent.agent.v1alpha.LivenessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x13/v1alpha/__livenessZ\x17\x12\x15/v1alpha/health/agent\x12\xa0\x01\n\tReadiness\x12%.agent.agent.v1alpha.ReadinessRequest\x1a&.agent.agent.v1alpha.ReadinessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x14/v1alpha/__readinessZ\x16\x12\x14/v1alpha/ready/agent\x12\xb5\x01\n\nCreateChat\x12&.agent.agent.v1alpha.CreateChatRequest\x1a\'.agent.agent.v1alpha.CreateChatResponse\"V\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02-\"(/v1alpha/namespaces/{namespace_id}/chats:\x01*\x12\xaf\x01\n\tListChats\x12%.agent.agent.v1alpha.ListChatsRequest\x1a&.agent.agent.v1alpha.ListChatsResponse\"S\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02*\x12(/v1alpha/namespaces/{namespace_id}/chats\x12\xc0\x01\n\nUpdateChat\x12&.agent.agent.v1alpha.UpdateChatRequest\x1a\'.agent.agent.v1alpha.UpdateChatResponse\"a\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x38\x1a\x33/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}:\x01*\x12\xb4\x01\n\x07GetChat\x12#.agent.agent.v1alpha.GetChatRequest\x1a$.agent.agent.v1alpha.GetChatResponse\"^\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x35\x12\x33/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}\x12\xbd\x01\n\nDeleteChat\x12&.agent.agent.v1alpha.DeleteChatRequest\x1a\'.agent.agent.v1alpha.DeleteChatResponse\"^\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x35*3/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}\x12\xcc\x01\n\x0cListMessages\x12(.agent.agent.v1alpha.ListMessagesRequest\x1a).agent.agent.v1alpha.ListMessagesResponse\"g\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>\x12</v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/messages\x12\xdb\x01\n\rChatWithAgent\x12).agent.agent.v1alpha.ChatWithAgentRequest\x1a*.agent.agent.v1alpha.ChatWithAgentResponse\"q\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02H\"C/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/chat-with-agent:\x01*0\x01\x12\xcf\x01\n\rBindChatTable\x12).agent.agent.v1alpha.BindChatTableRequest\x1a*.agent.agent.v1alpha.BindChatTableResponse\"g\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x43\">/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/bind-table:\x01*\x12\xd7\x01\n\x0fUnbindChatTable\x12+.agent.agent.v1alpha.UnbindChatTableRequest\x1a,.agent.agent.v1alpha.UnbindChatTableResponse\"i\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x45\"@/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/unbind-table:\x01*\x12\xcb\x01\n\x0eListChatTables\x12*.agent.agent.v1alpha.ListChatTablesRequest\x1a+.agent.agent.v1alpha.ListChatTablesResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/tables\x12\xae\x01\n\nListTables\x12&.agent.agent.v1alpha.ListTablesRequest\x1a\'.agent.agent.v1alpha.ListTablesResponse\"O\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02+\x12)/v1alpha/namespaces/{namespace_id}/tables\x12\xb8\x01\n\x0b\x43reateTable\x12\'.agent.agent.v1alpha.CreateTableRequest\x1a(.agent.agent.v1alpha.CreateTableResponse\"V\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x32\")/v1alpha/namespaces/{namespace_id}/tables:\x05table\x12\xb4\x01\n\x08GetTable\x12$.agent.agent.v1alpha.GetTableRequest\x1a%.agent.agent.v1alpha.GetTableResponse\"[\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x37\x12\x35/v1alpha/namespaces/{namespace_id}/tables/{table_uid}\x12\xc4\x01\n\x0bUpdateTable\x12\'.agent.agent.v1alpha.UpdateTableRequest\x1a(.agent.agent.v1alpha.UpdateTableResponse\"b\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>25/v1alpha/namespaces/{namespace_id}/tables/{table_uid}:\x05table\x12\xbd\x01\n\x0b\x44\x65leteTable\x12\'.agent.agent.v1alpha.DeleteTableRequest\x1a(.agent.agent.v1alpha.DeleteTableResponse\"[\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x37*5/v1alpha/namespaces/{namespace_id}/tables/{table_uid}\x12\x84\x02\n\x19\x43hatWithTableBuilderAgent\x12\x35.agent.agent.v1alpha.ChatWithTableBuilderAgentRequest\x1a\x36.agent.agent.v1alpha.ChatWithTableBuilderAgentResponse\"v\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02R\"M/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/chat-with-agent:\x01*0\x01\x12\x84\x02\n\x1dListTableBuilderAgentMessages\x12\x39.agent.agent.v1alpha.ListTableBuilderAgentMessagesRequest\x1a:.agent.agent.v1alpha.ListTableBuilderAgentMessagesResponse\"l\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02H\x12\x46/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/messages\x12\xeb\x01\n\x14GetColumnDefinitions\x12\x30.agent.agent.v1alpha.GetColumnDefinitionsRequest\x1a\x31.agent.agent.v1alpha.GetColumnDefinitionsResponse\"n\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02J\x12H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions\x12\x89\x02\n\x17UpdateColumnDefinitions\x12\x33.agent.agent.v1alpha.UpdateColumnDefinitionsRequest\x1a\x34.agent.agent.v1alpha.UpdateColumnDefinitionsResponse\"\x82\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02^\x1aH/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions:\x12\x63olumn_definitions\x12\xf5\x01\n\x13GetColumnDefinition\x12/.agent.agent.v1alpha.GetColumnDefinitionRequest\x1a\x30.agent.agent.v1alpha.GetColumnDefinitionResponse\"{\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}\x12\xf4\x01\n\x0fRecomputeColumn\x12+.agent.agent.v1alpha.RecomputeColumnRequest\x1a,.agent.agent.v1alpha.RecomputeColumnResponse\"\x85\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x61\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}/recompute\x12\xb9\x01\n\x08ListRows\x12$.agent.agent.v1alpha.ListRowsRequest\x1a%.agent.agent.v1alpha.ListRowsResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows\x12\xbd\x01\n\x06GetRow\x12\".agent.agent.v1alpha.GetRowRequest\x1a#.agent.agent.v1alpha.GetRowResponse\"j\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x46\x12\x44/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}\x12\xbf\x01\n\tInsertRow\x12%.agent.agent.v1alpha.InsertRowRequest\x1a&.agent.agent.v1alpha.InsertRowResponse\"c\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02?\":/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\x01*\x12\xc9\x01\n\tUpdateRow\x12%.agent.agent.v1alpha.UpdateRowRequest\x1a&.agent.agent.v1alpha.UpdateRowResponse\"m\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02I2D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}:\x01*\x12\xc2\x01\n\nUpdateRows\x12&.agent.agent.v1alpha.UpdateRowsRequest\x1a\'.agent.agent.v1alpha.UpdateRowsResponse\"c\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02?2:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\x01*\x12\xc6\x01\n\tDeleteRow\x12%.agent.agent.v1alpha.DeleteRowRequest\x1a&.agent.agent.v1alpha.DeleteRowResponse\"j\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x46*D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}\x12\xbf\x01\n\nDeleteRows\x12&.agent.agent.v1alpha.DeleteRowsRequest\x1a\'.agent.agent.v1alpha.DeleteRowsResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<*:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows\x12\xc1\x01\n\x08MoveRows\x12$.agent.agent.v1alpha.MoveRowsRequest\x1a%.agent.agent.v1alpha.MoveRowsResponse\"h\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x44\"?/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/move-rows:\x01*\x12\xd1\x01\n\x07GetCell\x12#.agent.agent.v1alpha.GetCellRequest\x1a$.agent.agent.v1alpha.GetCellResponse\"{\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}\x12\xdd\x01\n\nUpdateCell\x12&.agent.agent.v1alpha.UpdateCellRequest\x1a\'.agent.agent.v1alpha.UpdateCellResponse\"~\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02Z2U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}:\x01*\x12\xe1\x01\n\tResetCell\x12%.agent.agent.v1alpha.ResetCellRequest\x1a&.agent.agent.v1alpha.ResetCellResponse\"\x84\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02`\"[/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/reset:\x01*\x12\xf1\x01\n\rRecomputeCell\x12).agent.agent.v1alpha.RecomputeCellRequest\x1a*.agent.agent.v1alpha.RecomputeCellResponse\"\x88\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x64\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/recompute:\x01*\x12\xdd\x01\n\x08LockCell\x12$.agent.agent.v1alpha.LockCellRequest\x1a%.agent.agent.v1alpha.LockCellResponse\"\x83\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02_\"Z/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/lock:\x01*\x12\xe5\x01\n\nUnlockCell\x12&.agent.agent.v1alpha.UnlockCellRequest\x1a\'.agent.agent.v1alpha.UnlockCellResponse\"\x85\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x61\"\\/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/unlock:\x01*\x12\xcf\x01\n\x0eGetTableEvents\x12*.agent.agent.v1alpha.GetTableEventsRequest\x1a+.agent.agent.v1alpha.GetTableEventsResponse\"b\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>\x12</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/events0\x01\x12\xc7\x01\n\x0b\x45xportTable\x12\'.agent.agent.v1alpha.ExportTableRequest\x1a(.agent.agent.v1alpha.ExportTableResponse\"e\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/export:\x01*\x1a\x1b\x92\x41\x18\x12\x16Public Agent endpointsB\xe4\x01\n\x17\x63om.agent.agent.v1alphaB\x17\x41gentPublicServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.agent_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\027AgentPublicServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _AGENTPUBLICSERVICE._options = None
  _AGENTPUBLICSERVICE._serialized_options = b'\222A\030\022\026Public Agent endpoints'
  _AGENTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\023/v1alpha/__livenessZ\027\022\025/v1alpha/health/agent'
  _AGENTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\024/v1alpha/__readinessZ\026\022\024/v1alpha/ready/agent'
  _AGENTPUBLICSERVICE.methods_by_name['CreateChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['CreateChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002-\"(/v1alpha/namespaces/{namespace_id}/chats:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListChats']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListChats']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002*\022(/v1alpha/namespaces/{namespace_id}/chats'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0028\0323/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0025\0223/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0025*3/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['ListMessages']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListMessages']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>\022</v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/messages'
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithAgent']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithAgent']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002H\"C/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/chat-with-agent:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['BindChatTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['BindChatTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002C\">/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/bind-table:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UnbindChatTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UnbindChatTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002E\"@/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/unbind-table:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListChatTables']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListChatTables']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/tables'
  _AGENTPUBLICSERVICE.methods_by_name['ListTables']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListTables']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002+\022)/v1alpha/namespaces/{namespace_id}/tables'
  _AGENTPUBLICSERVICE.methods_by_name['CreateTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['CreateTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0022\")/v1alpha/namespaces/{namespace_id}/tables:\005table'
  _AGENTPUBLICSERVICE.methods_by_name['GetTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0027\0225/v1alpha/namespaces/{namespace_id}/tables/{table_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>25/v1alpha/namespaces/{namespace_id}/tables/{table_uid}:\005table'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0027*5/v1alpha/namespaces/{namespace_id}/tables/{table_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithTableBuilderAgent']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithTableBuilderAgent']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002R\"M/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/chat-with-agent:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListTableBuilderAgentMessages']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListTableBuilderAgentMessages']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002H\022F/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/messages'
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinitions']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinitions']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002J\022H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateColumnDefinitions']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateColumnDefinitions']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002^\032H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions:\022column_definitions'
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinition']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinition']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeColumn']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeColumn']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002a\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}/recompute'
  _AGENTPUBLICSERVICE.methods_by_name['ListRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows'
  _AGENTPUBLICSERVICE.methods_by_name['GetRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002F\022D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['InsertRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['InsertRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002?\":/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002I2D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002?2:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002F*D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<*:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows'
  _AGENTPUBLICSERVICE.methods_by_name['MoveRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['MoveRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002D\"?/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/move-rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002Z2U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ResetCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ResetCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002`\"[/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/reset:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002d\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/recompute:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['LockCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['LockCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002_\"Z/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/lock:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UnlockCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UnlockCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002a\"\\/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/unlock:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetTableEvents']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetTableEvents']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>\022</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/events'
  _AGENTPUBLICSERVICE.methods_by_name['ExportTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ExportTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/export:\001*'
  _globals['_AGENTPUBLICSERVICE']._serialized_start=277
  _globals['_AGENTPUBLICSERVICE']._serialized_end=8451
# @@protoc_insertion_point(module_scope)
