# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61gent/agent/v1alpha/agent.proto\x12\x13\x61gent.agent.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"{\n\x10LivenessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"|\n\x11ReadinessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponseB\xd7\x01\n\x17\x63om.agent.agent.v1alphaB\nAgentProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.agent_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\nAgentProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._options = None
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSRESPONSE.fields_by_name['health_check_response']._options = None
  _READINESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _globals['_LIVENESSREQUEST']._serialized_start=135
  _globals['_LIVENESSREQUEST']._serialized_end=284
  _globals['_LIVENESSRESPONSE']._serialized_start=286
  _globals['_LIVENESSRESPONSE']._serialized_end=409
  _globals['_READINESSREQUEST']._serialized_start=412
  _globals['_READINESSREQUEST']._serialized_end=562
  _globals['_READINESSRESPONSE']._serialized_start=564
  _globals['_READINESSRESPONSE']._serialized_end=688
# @@protoc_insertion_point(module_scope)
