# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent.agent.v1alpha import common_pb2 as agent_dot_agent_dot_v1alpha_dot_common__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61gent/agent/v1alpha/table.proto\x12\x13\x61gent.agent.v1alpha\x1a agent/agent/v1alpha/common.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdd\x03\n\x05Table\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x19\n\x05title\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x05title\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12\x38\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x08metadata\x12@\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12N\n\x0c\x61gent_config\x18\x08 \x01(\x0b\x32&.agent.agent.v1alpha.Table.AgentConfigB\x03\xe0\x41\x02R\x0b\x61gentConfig\x12\"\n\ndraft_mode\x18\t \x01(\x08\x42\x03\xe0\x41\x02R\tdraftMode\x1a\x43\n\x0b\x41gentConfig\x12\x34\n\x13\x65nable_transparency\x18\x01 \x01(\x08\x42\x03\xe0\x41\x02R\x12\x65nableTransparencyJ\x04\x08\x02\x10\x03\"\x81\x01\n\x11ListTablesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01R\tpageToken\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\"\x9e\x01\n\x12ListTablesResponse\x12\x37\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x06tables\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"s\n\x12\x43reateTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x35\n\x05table\x18\x02 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x02R\x05table\"L\n\x13\x43reateTableResponse\x12\x35\n\x05table\x18\x01 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\"[\n\x0fGetTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"I\n\x10GetTableResponse\x12\x35\n\x05table\x18\x01 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\"\xd2\x01\n\x12UpdateTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x30\n\x05table\x18\x03 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableR\x05table\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"L\n\x13UpdateTableResponse\x12\x35\n\x05table\x18\x01 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\"^\n\x12\x44\x65leteTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"\x15\n\x13\x44\x65leteTableResponse\"\x9e\x02\n\x0cNumberFormat\x12\x45\n\x06\x66ormat\x18\x01 \x01(\x0e\x32(.agent.agent.v1alpha.NumberFormat.FormatB\x03\xe0\x41\x02R\x06\x66ormat\x12*\n\x0e\x64\x65\x63imal_places\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\rdecimalPlaces\x12(\n\rcurrency_code\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0c\x63urrencyCode\"q\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x46ORMAT_PLAIN\x10\x01\x12\x11\n\rFORMAT_COMMAS\x10\x02\x12\x13\n\x0f\x46ORMAT_CURRENCY\x10\x03\x12\x15\n\x11\x46ORMAT_PERCENTAGE\x10\x04\"\xe0\n\n\x10\x43olumnDefinition\x12\"\n\ncolumn_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\tcolumnUid\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\x32\n\x04type\x18\x03 \x01(\x0e\x32\x19.agent.agent.v1alpha.TypeB\x03\xe0\x41\x02R\x04type\x12\x19\n\x05order\x18\x04 \x01(\x05\x42\x03\xe0\x41\x02R\x05order\x12Y\n\x0c\x61gent_config\x18\x05 \x01(\x0b\x32\x31.agent.agent.v1alpha.ColumnDefinition.AgentConfigB\x03\xe0\x41\x01R\x0b\x61gentConfig\x12\x43\n\x04sort\x18\x06 \x01(\x0e\x32*.agent.agent.v1alpha.ColumnDefinition.SortB\x03\xe0\x41\x01R\x04sort\x12%\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12M\n\rnumber_format\x18\x08 \x01(\x0b\x32!.agent.agent.v1alpha.NumberFormatB\x03\xe0\x41\x01H\x00R\x0cnumberFormat\x12R\n\tselection\x18\t \x01(\x0b\x32/.agent.agent.v1alpha.ColumnDefinition.SelectionB\x03\xe0\x41\x01R\tselection\x1a\xdf\x02\n\x0b\x41gentConfig\x12\'\n\x0cinstructions\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0cinstructions\x12/\n\x11\x65nable_web_search\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02R\x0f\x65nableWebSearch\x12J\n\x1c\x65nable_automatic_computation\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01H\x00R\x1a\x65nableAutomaticComputation\x88\x01\x01\x12X\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\x39.agent.agent.v1alpha.ColumnDefinition.AgentConfig.ContextB\x03\xe0\x41\x01R\x07\x63ontext\x1a/\n\x07\x43ontext\x12$\n\x0b\x63olumn_uids\x18\x01 \x03(\tB\x03\xe0\x41\x01R\ncolumnUidsB\x1f\n\x1d_enable_automatic_computation\x1a\xa2\x03\n\tSelection\x12V\n\x04type\x18\x01 \x01(\x0e\x32=.agent.agent.v1alpha.ColumnDefinition.Selection.SelectionTypeB\x03\xe0\x41\x02R\x04type\x12U\n\x07options\x18\x02 \x03(\x0b\x32\x36.agent.agent.v1alpha.ColumnDefinition.Selection.OptionB\x03\xe0\x41\x01R\x07options\x1a\x80\x01\n\x06Option\x12(\n\x0cstring_value\x18\x01 \x01(\tB\x03\xe0\x41\x01H\x00R\x0bstringValue\x12(\n\x0cnumber_value\x18\x02 \x01(\x02\x42\x03\xe0\x41\x01H\x00R\x0bnumberValue\x12\x19\n\x05\x63olor\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x05\x63olorB\x07\n\x05value\"c\n\rSelectionType\x12\x1e\n\x1aSELECTION_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SELECTION_TYPE_NONE\x10\x01\x12\x19\n\x15SELECTION_TYPE_SINGLE\x10\x02\"E\n\x04Sort\x12\x14\n\x10SORT_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ASCENDING\x10\x01\x12\x13\n\x0fSORT_DESCENDING\x10\x02\x42\x08\n\x06\x66ormat\"g\n\x1bGetColumnDefinitionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"\x89\x02\n\x1cGetColumnDefinitionsResponse\x12|\n\x12\x63olumn_definitions\x18\x01 \x03(\x0b\x32H.agent.agent.v1alpha.GetColumnDefinitionsResponse.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\xd2\x02\n\x1eUpdateColumnDefinitionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12y\n\x12\x63olumn_definitions\x18\x03 \x03(\x0b\x32J.agent.agent.v1alpha.UpdateColumnDefinitionsRequest.ColumnDefinitionsEntryR\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x8f\x02\n\x1fUpdateColumnDefinitionsResponse\x12\x7f\n\x12\x63olumn_definitions\x18\x01 \x03(\x0b\x32K.agent.agent.v1alpha.UpdateColumnDefinitionsResponse.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x8a\x01\n\x1aGetColumnDefinitionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\"\n\ncolumn_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tcolumnUid\"v\n\x1bGetColumnDefinitionResponse\x12W\n\x11\x63olumn_definition\x18\x01 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionB\x03\xe0\x41\x03R\x10\x63olumnDefinition\"\x86\x01\n\x16RecomputeColumnRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\"\n\ncolumn_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tcolumnUid\"\x19\n\x17RecomputeColumnResponse\"\xd0\x07\n\x04\x43\x65ll\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\"\n\ncolumn_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\tcolumnUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x06rowUid\x12@\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12\x32\n\x04type\x18\x05 \x01(\x0e\x32\x19.agent.agent.v1alpha.TypeB\x03\xe0\x41\x03R\x04type\x12I\n\x0cstring_value\x18\x06 \x01(\x0b\x32\x1f.agent.agent.v1alpha.StringCellB\x03\xe0\x41\x01H\x00R\x0bstringValue\x12I\n\x0cnumber_value\x18\x07 \x01(\x0b\x32\x1f.agent.agent.v1alpha.NumberCellB\x03\xe0\x41\x01H\x00R\x0bnumberValue\x12L\n\rboolean_value\x18\x08 \x01(\x0b\x32 .agent.agent.v1alpha.BooleanCellB\x03\xe0\x41\x01H\x00R\x0c\x62ooleanValue\x12\x43\n\nfile_value\x18\t \x01(\x0b\x32\x1d.agent.agent.v1alpha.FileCellB\x03\xe0\x41\x01H\x00R\tfileValue\x12O\n\x0e\x64ocument_value\x18\n \x01(\x0b\x32!.agent.agent.v1alpha.DocumentCellB\x03\xe0\x41\x01H\x00R\rdocumentValue\x12\x38\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01R\x08metadata\x12<\n\x06status\x18\x0c \x01(\x0e\x32\x1f.agent.agent.v1alpha.CellStatusB\x03\xe0\x41\x03R\x06status\x12@\n\tcitations\x18\x0e \x03(\x0b\x32\x1d.agent.agent.v1alpha.CitationB\x03\xe0\x41\x03R\tcitations\x12O\n\x0ctransparency\x18\r \x01(\x0b\x32&.agent.agent.v1alpha.Cell.TransparencyB\x03\xe0\x41\x03R\x0ctransparency\x12\x42\n\nlock_state\x18\x0f \x01(\x0e\x32\x1e.agent.agent.v1alpha.LockStateB\x03\xe0\x41\x03R\tlockState\x1a\'\n\x0cTransparency\x12\x17\n\x04text\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04textB\x07\n\x05value\"\n\n\x08NullCell\"\xa5\x01\n\nStringCell\x12\x1b\n\x05value\x18\x01 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x05value\x12\'\n\nuser_input\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x00R\tuserInput\x88\x01\x01\x12/\n\x0e\x63omputed_value\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\rcomputedValue\x88\x01\x01\x42\r\n\x0b_user_inputB\x11\n\x0f_computed_value\"\xa5\x01\n\nNumberCell\x12\x1b\n\x05value\x18\x01 \x01(\x02\x42\x05\x18\x01\xe0\x41\x02R\x05value\x12\'\n\nuser_input\x18\x02 \x01(\x02\x42\x03\xe0\x41\x01H\x00R\tuserInput\x88\x01\x01\x12/\n\x0e\x63omputed_value\x18\x03 \x01(\x02\x42\x03\xe0\x41\x03H\x01R\rcomputedValue\x88\x01\x01\x42\r\n\x0b_user_inputB\x11\n\x0f_computed_value\"\xa6\x01\n\x0b\x42ooleanCell\x12\x1b\n\x05value\x18\x01 \x01(\x08\x42\x05\x18\x01\xe0\x41\x02R\x05value\x12\'\n\nuser_input\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01H\x00R\tuserInput\x88\x01\x01\x12/\n\x0e\x63omputed_value\x18\x03 \x01(\x08\x42\x03\xe0\x41\x03H\x01R\rcomputedValue\x88\x01\x01\x42\r\n\x0b_user_inputB\x11\n\x0f_computed_value\"\xf0\x01\n\x08\x46ileCell\x12!\n\tnamespace\x18\x01 \x01(\tB\x03\xe0\x41\x03R\tnamespace\x12\x1e\n\x08\x66ile_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x07\x66ileUid\x12\"\n\nobject_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tobjectUid\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x04name\x12 \n\tmime_type\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08mimeType\x12\"\n\ncatalog_id\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tcatalogId\x12\x1e\n\x08\x66ile_url\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x07\x66ileUrl\"\xb0\x01\n\x0c\x44ocumentCell\x12!\n\tnamespace\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tnamespace\x12\x1e\n\x08\x66ile_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x66ileUid\x12\"\n\nobject_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tobjectUid\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\tmime_type\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08mimeType\"\xd0\x02\n\x03Row\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12>\n\x05\x63\x65lls\x18\x02 \x03(\x0b\x32#.agent.agent.v1alpha.Row.CellsEntryB\x03\xe0\x41\x02R\x05\x63\x65lls\x12\x19\n\x05order\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x05order\x12@\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x1aS\n\nCellsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12/\n\x05value\x18\x02 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellR\x05value:\x02\x38\x01\"\xad\x01\n\x0fListRowsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12 \n\tpage_size\x18\x05 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12\"\n\npage_token\x18\x06 \x01(\tB\x03\xe0\x41\x01R\tpageTokenJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\x96\x01\n\x10ListRowsResponse\x12\x31\n\x04rows\x18\x01 \x03(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x04rows\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xcb\x01\n\x10InsertRowRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12*\n\x03row\x18\x03 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowR\x03row\x12.\n\x0e\x62\x65\x66ore_row_uid\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x0c\x62\x65\x66oreRowUid\x88\x01\x01\x42\x11\n\x0f_before_row_uid\"D\n\x11InsertRowResponse\x12/\n\x03row\x18\x01 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x03row\"\xa6\x01\n\x10UpdateRowRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12*\n\x03row\x18\x04 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowR\x03row\"D\n\x11UpdateRowResponse\x12/\n\x03row\x18\x01 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x03row\"w\n\rGetRowRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\"A\n\x0eGetRowResponse\x12/\n\x03row\x18\x01 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x03row\"\x8b\x01\n\x11UpdateRowsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12,\n\x04rows\x18\x03 \x03(\x0b\x32\x18.agent.agent.v1alpha.RowR\x04rows\"G\n\x12UpdateRowsResponse\x12\x31\n\x04rows\x18\x01 \x03(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x04rows\"z\n\x10\x44\x65leteRowRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\"\x13\n\x11\x44\x65leteRowResponse\"}\n\x11\x44\x65leteRowsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1e\n\x08row_uids\x18\x03 \x03(\tB\x03\xe0\x41\x02R\x07rowUids\"\x14\n\x12\x44\x65leteRowsResponse\"\xbe\x01\n\x0fMoveRowsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1e\n\x08row_uids\x18\x03 \x03(\tB\x03\xe0\x41\x02R\x07rowUids\x12.\n\x0e\x62\x65\x66ore_row_uid\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x0c\x62\x65\x66oreRowUid\x88\x01\x01\x42\x11\n\x0f_before_row_uid\"\x12\n\x10MoveRowsResponse\"\x98\x01\n\x0eGetCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\"E\n\x0fGetCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\xca\x01\n\x11UpdateCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\x12-\n\x04\x63\x65ll\x18\x05 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellR\x04\x63\x65ll\"H\n\x12UpdateCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\x9e\x01\n\x14RecomputeCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\"K\n\x15RecomputeCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\x9a\x01\n\x10ResetCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\"G\n\x11ResetCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\x99\x01\n\x0fLockCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\"F\n\x10LockCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\x9b\x01\n\x11UnlockCellRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1c\n\x07row_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x06rowUid\x12\x1e\n\x08\x63\x65ll_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63\x65llUid\"H\n\x12UnlockCellResponse\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\"\x9e\x01\n\x12\x45xportTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12>\n\x06\x66ormat\x18\x03 \x01(\x0e\x32!.agent.agent.v1alpha.ExportFormatB\x03\xe0\x41\x02R\x06\x66ormat\".\n\x13\x45xportTableResponse\x12\x17\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x03\xe0\x41\x03R\x04\x64\x61ta\"a\n\x15GetTableEventsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"T\n\x16GetTableEventsResponse\x12:\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1f.agent.agent.v1alpha.TableEventB\x03\xe0\x41\x03R\x05\x65vent\"\x9e\x06\n\nTableEvent\x12\x19\n\x05\x65vent\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x05\x65vent\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12X\n\x13table_updated_event\x18\x03 \x01(\x0b\x32&.agent.agent.v1alpha.TableUpdatedEventH\x00R\x11tableUpdatedEvent\x12X\n\x13table_deleted_event\x18\x04 \x01(\x0b\x32&.agent.agent.v1alpha.TableDeletedEventH\x00R\x11tableDeletedEvent\x12}\n column_definitions_updated_event\x18\x05 \x01(\x0b\x32\x32.agent.agent.v1alpha.ColumnDefinitionsUpdatedEventH\x00R\x1d\x63olumnDefinitionsUpdatedEvent\x12U\n\x12row_inserted_event\x18\x06 \x01(\x0b\x32%.agent.agent.v1alpha.RowInsertedEventH\x00R\x10rowInsertedEvent\x12R\n\x11row_updated_event\x18\x07 \x01(\x0b\x32$.agent.agent.v1alpha.RowUpdatedEventH\x00R\x0frowUpdatedEvent\x12R\n\x11row_deleted_event\x18\x08 \x01(\x0b\x32$.agent.agent.v1alpha.RowDeletedEventH\x00R\x0frowDeletedEvent\x12O\n\x10rows_moved_event\x18\t \x01(\x0b\x32#.agent.agent.v1alpha.RowsMovedEventH\x00R\x0erowsMovedEvent\x12U\n\x12\x63\x65ll_updated_event\x18\n \x01(\x0b\x32%.agent.agent.v1alpha.CellUpdatedEventH\x00R\x10\x63\x65llUpdatedEventB\x06\n\x04\x64\x61ta\"J\n\x11TableUpdatedEvent\x12\x35\n\x05table\x18\x01 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\"\x13\n\x11TableDeletedEvent\"\x8b\x02\n\x1d\x43olumnDefinitionsUpdatedEvent\x12}\n\x12\x63olumn_definitions\x18\x01 \x03(\x0b\x32I.agent.agent.v1alpha.ColumnDefinitionsUpdatedEvent.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"n\n\x10RowInsertedEvent\x12/\n\x03row\x18\x01 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x03row\x12)\n\x0e\x62\x65\x66ore_row_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0c\x62\x65\x66oreRowUid\"B\n\x0fRowUpdatedEvent\x12/\n\x03row\x18\x01 \x01(\x0b\x32\x18.agent.agent.v1alpha.RowB\x03\xe0\x41\x03R\x03row\"/\n\x0fRowDeletedEvent\x12\x1c\n\x07row_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x06rowUid\"s\n\x0eRowsMovedEvent\x12\x1e\n\x08row_uids\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x07rowUids\x12.\n\x0e\x62\x65\x66ore_row_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03H\x00R\x0c\x62\x65\x66oreRowUid\x88\x01\x01\x42\x11\n\x0f_before_row_uid\"j\n\x10\x43\x65llUpdatedEvent\x12\x32\n\x04\x63\x65ll\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.CellB\x03\xe0\x41\x03R\x04\x63\x65ll\x12\"\n\ndelta_mode\x18\x02 \x01(\x08\x42\x03\xe0\x41\x03R\tdeltaMode\"\xf3\x02\n\x18GenerateMockTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12#\n\x08num_rows\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x07numRows\x88\x01\x01\x12\x39\n\x13\x65nable_transparency\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01H\x01R\x12\x65nableTransparency\x88\x01\x01\x12K\n\x04mode\x18\x05 \x01(\x0e\x32\x32.agent.agent.v1alpha.GenerateMockTableRequest.ModeB\x03\xe0\x41\x01R\x04mode\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tMODE_FILE\x10\x01\x12\x0e\n\nMODE_SHEET\x10\x02\x42\x0b\n\t_num_rowsB\x16\n\x14_enable_transparency\"\x1b\n\x19GenerateMockTableResponse\"\x80\x01\n\x14\x42indChatTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12 \n\ttable_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"\x17\n\x15\x42indChatTableResponse\"\x82\x01\n\x16UnbindChatTableRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12 \n\ttable_uid\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\"\x19\n\x17UnbindChatTableResponse\"_\n\x15ListChatTablesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\"Q\n\x16ListChatTablesResponse\x12\x37\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x06tables*r\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bTYPE_STRING\x10\x01\x12\x0f\n\x0bTYPE_NUMBER\x10\x02\x12\x10\n\x0cTYPE_BOOLEAN\x10\x03\x12\r\n\tTYPE_FILE\x10\x04\x12\x11\n\rTYPE_DOCUMENT\x10\x05*\xaf\x02\n\nCellStatus\x12\x1b\n\x17\x43\x45LL_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43\x45LL_STATUS_IDLE\x10\x01\x12\x1e\n\x1a\x43\x45LL_STATUS_DATA_UPLOADING\x10\x02\x12\x1c\n\x18\x43\x45LL_STATUS_DATA_PENDING\x10\x03\x12\x1f\n\x1b\x43\x45LL_STATUS_DATA_PROCESSING\x10\x04\x12\x1b\n\x17\x43\x45LL_STATUS_DATA_FAILED\x10\x05\x12$\n CELL_STATUS_TRANSPARENCY_PENDING\x10\x06\x12\'\n#CELL_STATUS_TRANSPARENCY_PROCESSING\x10\x07\x12#\n\x1f\x43\x45LL_STATUS_TRANSPARENCY_FAILED\x10\x08*W\n\tLockState\x12\x1a\n\x16LOCK_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11LOCK_STATE_LOCKED\x10\x01\x12\x17\n\x13LOCK_STATE_UNLOCKED\x10\x02*_\n\x0c\x45xportFormat\x12\x1d\n\x19\x45XPORT_FORMAT_UNSPECIFIED\x10\x00\x12\x15\n\x11\x45XPORT_FORMAT_CSV\x10\x01\x12\x19\n\x15\x45XPORT_FORMAT_PARQUET\x10\x02\x42\xd7\x01\n\x17\x63om.agent.agent.v1alphaB\nTableProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.table_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\nTableProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _TABLE_AGENTCONFIG.fields_by_name['enable_transparency']._options = None
  _TABLE_AGENTCONFIG.fields_by_name['enable_transparency']._serialized_options = b'\340A\002'
  _TABLE.fields_by_name['uid']._options = None
  _TABLE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['title']._options = None
  _TABLE.fields_by_name['title']._serialized_options = b'\340A\002'
  _TABLE.fields_by_name['description']._options = None
  _TABLE.fields_by_name['description']._serialized_options = b'\340A\001'
  _TABLE.fields_by_name['metadata']._options = None
  _TABLE.fields_by_name['metadata']._serialized_options = b'\340A\001'
  _TABLE.fields_by_name['create_time']._options = None
  _TABLE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['update_time']._options = None
  _TABLE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _TABLE.fields_by_name['agent_config']._options = None
  _TABLE.fields_by_name['agent_config']._serialized_options = b'\340A\002'
  _TABLE.fields_by_name['draft_mode']._options = None
  _TABLE.fields_by_name['draft_mode']._serialized_options = b'\340A\002'
  _LISTTABLESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTTABLESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTTABLESREQUEST.fields_by_name['page_token']._options = None
  _LISTTABLESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTTABLESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTTABLESRESPONSE.fields_by_name['tables']._options = None
  _LISTTABLESRESPONSE.fields_by_name['tables']._serialized_options = b'\340A\003'
  _LISTTABLESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTTABLESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTTABLESRESPONSE.fields_by_name['total_size']._options = None
  _LISTTABLESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _CREATETABLEREQUEST.fields_by_name['namespace_id']._options = None
  _CREATETABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATETABLEREQUEST.fields_by_name['table']._options = None
  _CREATETABLEREQUEST.fields_by_name['table']._serialized_options = b'\340A\002'
  _CREATETABLERESPONSE.fields_by_name['table']._options = None
  _CREATETABLERESPONSE.fields_by_name['table']._serialized_options = b'\340A\003'
  _GETTABLEREQUEST.fields_by_name['namespace_id']._options = None
  _GETTABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETTABLEREQUEST.fields_by_name['table_uid']._options = None
  _GETTABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETTABLERESPONSE.fields_by_name['table']._options = None
  _GETTABLERESPONSE.fields_by_name['table']._serialized_options = b'\340A\003'
  _UPDATETABLEREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATETABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATETABLEREQUEST.fields_by_name['table_uid']._options = None
  _UPDATETABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UPDATETABLEREQUEST.fields_by_name['update_mask']._options = None
  _UPDATETABLEREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATETABLERESPONSE.fields_by_name['table']._options = None
  _UPDATETABLERESPONSE.fields_by_name['table']._serialized_options = b'\340A\003'
  _DELETETABLEREQUEST.fields_by_name['namespace_id']._options = None
  _DELETETABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETETABLEREQUEST.fields_by_name['table_uid']._options = None
  _DELETETABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _NUMBERFORMAT.fields_by_name['format']._options = None
  _NUMBERFORMAT.fields_by_name['format']._serialized_options = b'\340A\002'
  _NUMBERFORMAT.fields_by_name['decimal_places']._options = None
  _NUMBERFORMAT.fields_by_name['decimal_places']._serialized_options = b'\340A\001'
  _NUMBERFORMAT.fields_by_name['currency_code']._options = None
  _NUMBERFORMAT.fields_by_name['currency_code']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_AGENTCONFIG_CONTEXT.fields_by_name['column_uids']._options = None
  _COLUMNDEFINITION_AGENTCONFIG_CONTEXT.fields_by_name['column_uids']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['instructions']._options = None
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['instructions']._serialized_options = b'\340A\002'
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['enable_web_search']._options = None
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['enable_web_search']._serialized_options = b'\340A\002'
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['enable_automatic_computation']._options = None
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['enable_automatic_computation']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['context']._options = None
  _COLUMNDEFINITION_AGENTCONFIG.fields_by_name['context']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['string_value']._options = None
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['string_value']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['number_value']._options = None
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['number_value']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['color']._options = None
  _COLUMNDEFINITION_SELECTION_OPTION.fields_by_name['color']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION_SELECTION.fields_by_name['type']._options = None
  _COLUMNDEFINITION_SELECTION.fields_by_name['type']._serialized_options = b'\340A\002'
  _COLUMNDEFINITION_SELECTION.fields_by_name['options']._options = None
  _COLUMNDEFINITION_SELECTION.fields_by_name['options']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['column_uid']._options = None
  _COLUMNDEFINITION.fields_by_name['column_uid']._serialized_options = b'\340A\003'
  _COLUMNDEFINITION.fields_by_name['name']._options = None
  _COLUMNDEFINITION.fields_by_name['name']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['type']._options = None
  _COLUMNDEFINITION.fields_by_name['type']._serialized_options = b'\340A\002'
  _COLUMNDEFINITION.fields_by_name['order']._options = None
  _COLUMNDEFINITION.fields_by_name['order']._serialized_options = b'\340A\002'
  _COLUMNDEFINITION.fields_by_name['agent_config']._options = None
  _COLUMNDEFINITION.fields_by_name['agent_config']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['sort']._options = None
  _COLUMNDEFINITION.fields_by_name['sort']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['description']._options = None
  _COLUMNDEFINITION.fields_by_name['description']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['number_format']._options = None
  _COLUMNDEFINITION.fields_by_name['number_format']._serialized_options = b'\340A\001'
  _COLUMNDEFINITION.fields_by_name['selection']._options = None
  _COLUMNDEFINITION.fields_by_name['selection']._serialized_options = b'\340A\001'
  _GETCOLUMNDEFINITIONSREQUEST.fields_by_name['namespace_id']._options = None
  _GETCOLUMNDEFINITIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETCOLUMNDEFINITIONSREQUEST.fields_by_name['table_uid']._options = None
  _GETCOLUMNDEFINITIONSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETCOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY._options = None
  _GETCOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _GETCOLUMNDEFINITIONSRESPONSE.fields_by_name['column_definitions']._options = None
  _GETCOLUMNDEFINITIONSRESPONSE.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _UPDATECOLUMNDEFINITIONSREQUEST_COLUMNDEFINITIONSENTRY._options = None
  _UPDATECOLUMNDEFINITIONSREQUEST_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _UPDATECOLUMNDEFINITIONSREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATECOLUMNDEFINITIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATECOLUMNDEFINITIONSREQUEST.fields_by_name['table_uid']._options = None
  _UPDATECOLUMNDEFINITIONSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UPDATECOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY._options = None
  _UPDATECOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _UPDATECOLUMNDEFINITIONSRESPONSE.fields_by_name['column_definitions']._options = None
  _UPDATECOLUMNDEFINITIONSRESPONSE.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['table_uid']._options = None
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['column_uid']._options = None
  _GETCOLUMNDEFINITIONREQUEST.fields_by_name['column_uid']._serialized_options = b'\340A\002'
  _GETCOLUMNDEFINITIONRESPONSE.fields_by_name['column_definition']._options = None
  _GETCOLUMNDEFINITIONRESPONSE.fields_by_name['column_definition']._serialized_options = b'\340A\003'
  _RECOMPUTECOLUMNREQUEST.fields_by_name['namespace_id']._options = None
  _RECOMPUTECOLUMNREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RECOMPUTECOLUMNREQUEST.fields_by_name['table_uid']._options = None
  _RECOMPUTECOLUMNREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _RECOMPUTECOLUMNREQUEST.fields_by_name['column_uid']._options = None
  _RECOMPUTECOLUMNREQUEST.fields_by_name['column_uid']._serialized_options = b'\340A\002'
  _CELL_TRANSPARENCY.fields_by_name['text']._options = None
  _CELL_TRANSPARENCY.fields_by_name['text']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['uid']._options = None
  _CELL.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['column_uid']._options = None
  _CELL.fields_by_name['column_uid']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['row_uid']._options = None
  _CELL.fields_by_name['row_uid']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['update_time']._options = None
  _CELL.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['type']._options = None
  _CELL.fields_by_name['type']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['string_value']._options = None
  _CELL.fields_by_name['string_value']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['number_value']._options = None
  _CELL.fields_by_name['number_value']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['boolean_value']._options = None
  _CELL.fields_by_name['boolean_value']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['file_value']._options = None
  _CELL.fields_by_name['file_value']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['document_value']._options = None
  _CELL.fields_by_name['document_value']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['metadata']._options = None
  _CELL.fields_by_name['metadata']._serialized_options = b'\340A\001'
  _CELL.fields_by_name['status']._options = None
  _CELL.fields_by_name['status']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['citations']._options = None
  _CELL.fields_by_name['citations']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['transparency']._options = None
  _CELL.fields_by_name['transparency']._serialized_options = b'\340A\003'
  _CELL.fields_by_name['lock_state']._options = None
  _CELL.fields_by_name['lock_state']._serialized_options = b'\340A\003'
  _STRINGCELL.fields_by_name['value']._options = None
  _STRINGCELL.fields_by_name['value']._serialized_options = b'\030\001\340A\002'
  _STRINGCELL.fields_by_name['user_input']._options = None
  _STRINGCELL.fields_by_name['user_input']._serialized_options = b'\340A\001'
  _STRINGCELL.fields_by_name['computed_value']._options = None
  _STRINGCELL.fields_by_name['computed_value']._serialized_options = b'\340A\001'
  _NUMBERCELL.fields_by_name['value']._options = None
  _NUMBERCELL.fields_by_name['value']._serialized_options = b'\030\001\340A\002'
  _NUMBERCELL.fields_by_name['user_input']._options = None
  _NUMBERCELL.fields_by_name['user_input']._serialized_options = b'\340A\001'
  _NUMBERCELL.fields_by_name['computed_value']._options = None
  _NUMBERCELL.fields_by_name['computed_value']._serialized_options = b'\340A\003'
  _BOOLEANCELL.fields_by_name['value']._options = None
  _BOOLEANCELL.fields_by_name['value']._serialized_options = b'\030\001\340A\002'
  _BOOLEANCELL.fields_by_name['user_input']._options = None
  _BOOLEANCELL.fields_by_name['user_input']._serialized_options = b'\340A\001'
  _BOOLEANCELL.fields_by_name['computed_value']._options = None
  _BOOLEANCELL.fields_by_name['computed_value']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['namespace']._options = None
  _FILECELL.fields_by_name['namespace']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['file_uid']._options = None
  _FILECELL.fields_by_name['file_uid']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['object_uid']._options = None
  _FILECELL.fields_by_name['object_uid']._serialized_options = b'\340A\002'
  _FILECELL.fields_by_name['name']._options = None
  _FILECELL.fields_by_name['name']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['mime_type']._options = None
  _FILECELL.fields_by_name['mime_type']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['catalog_id']._options = None
  _FILECELL.fields_by_name['catalog_id']._serialized_options = b'\340A\003'
  _FILECELL.fields_by_name['file_url']._options = None
  _FILECELL.fields_by_name['file_url']._serialized_options = b'\340A\003'
  _DOCUMENTCELL.fields_by_name['namespace']._options = None
  _DOCUMENTCELL.fields_by_name['namespace']._serialized_options = b'\340A\002'
  _DOCUMENTCELL.fields_by_name['file_uid']._options = None
  _DOCUMENTCELL.fields_by_name['file_uid']._serialized_options = b'\340A\002'
  _DOCUMENTCELL.fields_by_name['object_uid']._options = None
  _DOCUMENTCELL.fields_by_name['object_uid']._serialized_options = b'\340A\002'
  _DOCUMENTCELL.fields_by_name['name']._options = None
  _DOCUMENTCELL.fields_by_name['name']._serialized_options = b'\340A\002'
  _DOCUMENTCELL.fields_by_name['mime_type']._options = None
  _DOCUMENTCELL.fields_by_name['mime_type']._serialized_options = b'\340A\002'
  _ROW_CELLSENTRY._options = None
  _ROW_CELLSENTRY._serialized_options = b'8\001'
  _ROW.fields_by_name['uid']._options = None
  _ROW.fields_by_name['uid']._serialized_options = b'\340A\003'
  _ROW.fields_by_name['cells']._options = None
  _ROW.fields_by_name['cells']._serialized_options = b'\340A\002'
  _ROW.fields_by_name['order']._options = None
  _ROW.fields_by_name['order']._serialized_options = b'\340A\003'
  _ROW.fields_by_name['create_time']._options = None
  _ROW.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _ROW.fields_by_name['update_time']._options = None
  _ROW.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _LISTROWSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTROWSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTROWSREQUEST.fields_by_name['table_uid']._options = None
  _LISTROWSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _LISTROWSREQUEST.fields_by_name['page_size']._options = None
  _LISTROWSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTROWSREQUEST.fields_by_name['page_token']._options = None
  _LISTROWSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTROWSRESPONSE.fields_by_name['rows']._options = None
  _LISTROWSRESPONSE.fields_by_name['rows']._serialized_options = b'\340A\003'
  _LISTROWSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTROWSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTROWSRESPONSE.fields_by_name['total_size']._options = None
  _LISTROWSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _INSERTROWREQUEST.fields_by_name['namespace_id']._options = None
  _INSERTROWREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _INSERTROWREQUEST.fields_by_name['table_uid']._options = None
  _INSERTROWREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _INSERTROWREQUEST.fields_by_name['before_row_uid']._options = None
  _INSERTROWREQUEST.fields_by_name['before_row_uid']._serialized_options = b'\340A\001'
  _INSERTROWRESPONSE.fields_by_name['row']._options = None
  _INSERTROWRESPONSE.fields_by_name['row']._serialized_options = b'\340A\003'
  _UPDATEROWREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATEROWREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATEROWREQUEST.fields_by_name['table_uid']._options = None
  _UPDATEROWREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UPDATEROWREQUEST.fields_by_name['row_uid']._options = None
  _UPDATEROWREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _UPDATEROWRESPONSE.fields_by_name['row']._options = None
  _UPDATEROWRESPONSE.fields_by_name['row']._serialized_options = b'\340A\003'
  _GETROWREQUEST.fields_by_name['namespace_id']._options = None
  _GETROWREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETROWREQUEST.fields_by_name['table_uid']._options = None
  _GETROWREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETROWREQUEST.fields_by_name['row_uid']._options = None
  _GETROWREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _GETROWRESPONSE.fields_by_name['row']._options = None
  _GETROWRESPONSE.fields_by_name['row']._serialized_options = b'\340A\003'
  _UPDATEROWSREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATEROWSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATEROWSREQUEST.fields_by_name['table_uid']._options = None
  _UPDATEROWSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UPDATEROWSRESPONSE.fields_by_name['rows']._options = None
  _UPDATEROWSRESPONSE.fields_by_name['rows']._serialized_options = b'\340A\003'
  _DELETEROWREQUEST.fields_by_name['namespace_id']._options = None
  _DELETEROWREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETEROWREQUEST.fields_by_name['table_uid']._options = None
  _DELETEROWREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _DELETEROWREQUEST.fields_by_name['row_uid']._options = None
  _DELETEROWREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _DELETEROWSREQUEST.fields_by_name['namespace_id']._options = None
  _DELETEROWSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETEROWSREQUEST.fields_by_name['table_uid']._options = None
  _DELETEROWSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _DELETEROWSREQUEST.fields_by_name['row_uids']._options = None
  _DELETEROWSREQUEST.fields_by_name['row_uids']._serialized_options = b'\340A\002'
  _MOVEROWSREQUEST.fields_by_name['namespace_id']._options = None
  _MOVEROWSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _MOVEROWSREQUEST.fields_by_name['table_uid']._options = None
  _MOVEROWSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _MOVEROWSREQUEST.fields_by_name['row_uids']._options = None
  _MOVEROWSREQUEST.fields_by_name['row_uids']._serialized_options = b'\340A\002'
  _MOVEROWSREQUEST.fields_by_name['before_row_uid']._options = None
  _MOVEROWSREQUEST.fields_by_name['before_row_uid']._serialized_options = b'\340A\001'
  _GETCELLREQUEST.fields_by_name['namespace_id']._options = None
  _GETCELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETCELLREQUEST.fields_by_name['table_uid']._options = None
  _GETCELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETCELLREQUEST.fields_by_name['row_uid']._options = None
  _GETCELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _GETCELLREQUEST.fields_by_name['cell_uid']._options = None
  _GETCELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _GETCELLRESPONSE.fields_by_name['cell']._options = None
  _GETCELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _UPDATECELLREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATECELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATECELLREQUEST.fields_by_name['table_uid']._options = None
  _UPDATECELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UPDATECELLREQUEST.fields_by_name['row_uid']._options = None
  _UPDATECELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _UPDATECELLREQUEST.fields_by_name['cell_uid']._options = None
  _UPDATECELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _UPDATECELLRESPONSE.fields_by_name['cell']._options = None
  _UPDATECELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _RECOMPUTECELLREQUEST.fields_by_name['namespace_id']._options = None
  _RECOMPUTECELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RECOMPUTECELLREQUEST.fields_by_name['table_uid']._options = None
  _RECOMPUTECELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _RECOMPUTECELLREQUEST.fields_by_name['row_uid']._options = None
  _RECOMPUTECELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _RECOMPUTECELLREQUEST.fields_by_name['cell_uid']._options = None
  _RECOMPUTECELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _RECOMPUTECELLRESPONSE.fields_by_name['cell']._options = None
  _RECOMPUTECELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _RESETCELLREQUEST.fields_by_name['namespace_id']._options = None
  _RESETCELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _RESETCELLREQUEST.fields_by_name['table_uid']._options = None
  _RESETCELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _RESETCELLREQUEST.fields_by_name['row_uid']._options = None
  _RESETCELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _RESETCELLREQUEST.fields_by_name['cell_uid']._options = None
  _RESETCELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _RESETCELLRESPONSE.fields_by_name['cell']._options = None
  _RESETCELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _LOCKCELLREQUEST.fields_by_name['namespace_id']._options = None
  _LOCKCELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LOCKCELLREQUEST.fields_by_name['table_uid']._options = None
  _LOCKCELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _LOCKCELLREQUEST.fields_by_name['row_uid']._options = None
  _LOCKCELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _LOCKCELLREQUEST.fields_by_name['cell_uid']._options = None
  _LOCKCELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _LOCKCELLRESPONSE.fields_by_name['cell']._options = None
  _LOCKCELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _UNLOCKCELLREQUEST.fields_by_name['namespace_id']._options = None
  _UNLOCKCELLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UNLOCKCELLREQUEST.fields_by_name['table_uid']._options = None
  _UNLOCKCELLREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UNLOCKCELLREQUEST.fields_by_name['row_uid']._options = None
  _UNLOCKCELLREQUEST.fields_by_name['row_uid']._serialized_options = b'\340A\002'
  _UNLOCKCELLREQUEST.fields_by_name['cell_uid']._options = None
  _UNLOCKCELLREQUEST.fields_by_name['cell_uid']._serialized_options = b'\340A\002'
  _UNLOCKCELLRESPONSE.fields_by_name['cell']._options = None
  _UNLOCKCELLRESPONSE.fields_by_name['cell']._serialized_options = b'\340A\003'
  _EXPORTTABLEREQUEST.fields_by_name['namespace_id']._options = None
  _EXPORTTABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _EXPORTTABLEREQUEST.fields_by_name['table_uid']._options = None
  _EXPORTTABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _EXPORTTABLEREQUEST.fields_by_name['format']._options = None
  _EXPORTTABLEREQUEST.fields_by_name['format']._serialized_options = b'\340A\002'
  _EXPORTTABLERESPONSE.fields_by_name['data']._options = None
  _EXPORTTABLERESPONSE.fields_by_name['data']._serialized_options = b'\340A\003'
  _GETTABLEEVENTSREQUEST.fields_by_name['namespace_id']._options = None
  _GETTABLEEVENTSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETTABLEEVENTSREQUEST.fields_by_name['table_uid']._options = None
  _GETTABLEEVENTSREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GETTABLEEVENTSRESPONSE.fields_by_name['event']._options = None
  _GETTABLEEVENTSRESPONSE.fields_by_name['event']._serialized_options = b'\340A\003'
  _TABLEEVENT.fields_by_name['event']._options = None
  _TABLEEVENT.fields_by_name['event']._serialized_options = b'\340A\003'
  _TABLEEVENT.fields_by_name['id']._options = None
  _TABLEEVENT.fields_by_name['id']._serialized_options = b'\340A\003'
  _TABLEUPDATEDEVENT.fields_by_name['table']._options = None
  _TABLEUPDATEDEVENT.fields_by_name['table']._serialized_options = b'\340A\003'
  _COLUMNDEFINITIONSUPDATEDEVENT_COLUMNDEFINITIONSENTRY._options = None
  _COLUMNDEFINITIONSUPDATEDEVENT_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _COLUMNDEFINITIONSUPDATEDEVENT.fields_by_name['column_definitions']._options = None
  _COLUMNDEFINITIONSUPDATEDEVENT.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _ROWINSERTEDEVENT.fields_by_name['row']._options = None
  _ROWINSERTEDEVENT.fields_by_name['row']._serialized_options = b'\340A\003'
  _ROWINSERTEDEVENT.fields_by_name['before_row_uid']._options = None
  _ROWINSERTEDEVENT.fields_by_name['before_row_uid']._serialized_options = b'\340A\003'
  _ROWUPDATEDEVENT.fields_by_name['row']._options = None
  _ROWUPDATEDEVENT.fields_by_name['row']._serialized_options = b'\340A\003'
  _ROWDELETEDEVENT.fields_by_name['row_uid']._options = None
  _ROWDELETEDEVENT.fields_by_name['row_uid']._serialized_options = b'\340A\003'
  _ROWSMOVEDEVENT.fields_by_name['row_uids']._options = None
  _ROWSMOVEDEVENT.fields_by_name['row_uids']._serialized_options = b'\340A\003'
  _ROWSMOVEDEVENT.fields_by_name['before_row_uid']._options = None
  _ROWSMOVEDEVENT.fields_by_name['before_row_uid']._serialized_options = b'\340A\003'
  _CELLUPDATEDEVENT.fields_by_name['cell']._options = None
  _CELLUPDATEDEVENT.fields_by_name['cell']._serialized_options = b'\340A\003'
  _CELLUPDATEDEVENT.fields_by_name['delta_mode']._options = None
  _CELLUPDATEDEVENT.fields_by_name['delta_mode']._serialized_options = b'\340A\003'
  _GENERATEMOCKTABLEREQUEST.fields_by_name['namespace_id']._options = None
  _GENERATEMOCKTABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GENERATEMOCKTABLEREQUEST.fields_by_name['table_uid']._options = None
  _GENERATEMOCKTABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _GENERATEMOCKTABLEREQUEST.fields_by_name['num_rows']._options = None
  _GENERATEMOCKTABLEREQUEST.fields_by_name['num_rows']._serialized_options = b'\340A\001'
  _GENERATEMOCKTABLEREQUEST.fields_by_name['enable_transparency']._options = None
  _GENERATEMOCKTABLEREQUEST.fields_by_name['enable_transparency']._serialized_options = b'\340A\001'
  _GENERATEMOCKTABLEREQUEST.fields_by_name['mode']._options = None
  _GENERATEMOCKTABLEREQUEST.fields_by_name['mode']._serialized_options = b'\340A\001'
  _BINDCHATTABLEREQUEST.fields_by_name['namespace_id']._options = None
  _BINDCHATTABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _BINDCHATTABLEREQUEST.fields_by_name['chat_uid']._options = None
  _BINDCHATTABLEREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _BINDCHATTABLEREQUEST.fields_by_name['table_uid']._options = None
  _BINDCHATTABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _UNBINDCHATTABLEREQUEST.fields_by_name['namespace_id']._options = None
  _UNBINDCHATTABLEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UNBINDCHATTABLEREQUEST.fields_by_name['chat_uid']._options = None
  _UNBINDCHATTABLEREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _UNBINDCHATTABLEREQUEST.fields_by_name['table_uid']._options = None
  _UNBINDCHATTABLEREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _LISTCHATTABLESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCHATTABLESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTCHATTABLESREQUEST.fields_by_name['chat_uid']._options = None
  _LISTCHATTABLESREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _LISTCHATTABLESRESPONSE.fields_by_name['tables']._options = None
  _LISTCHATTABLESRESPONSE.fields_by_name['tables']._serialized_options = b'\340A\003'
  _globals['_TYPE']._serialized_start=13206
  _globals['_TYPE']._serialized_end=13320
  _globals['_CELLSTATUS']._serialized_start=13323
  _globals['_CELLSTATUS']._serialized_end=13626
  _globals['_LOCKSTATE']._serialized_start=13628
  _globals['_LOCKSTATE']._serialized_end=13715
  _globals['_EXPORTFORMAT']._serialized_start=13717
  _globals['_EXPORTFORMAT']._serialized_end=13812
  _globals['_TABLE']._serialized_start=221
  _globals['_TABLE']._serialized_end=698
  _globals['_TABLE_AGENTCONFIG']._serialized_start=625
  _globals['_TABLE_AGENTCONFIG']._serialized_end=692
  _globals['_LISTTABLESREQUEST']._serialized_start=701
  _globals['_LISTTABLESREQUEST']._serialized_end=830
  _globals['_LISTTABLESRESPONSE']._serialized_start=833
  _globals['_LISTTABLESRESPONSE']._serialized_end=991
  _globals['_CREATETABLEREQUEST']._serialized_start=993
  _globals['_CREATETABLEREQUEST']._serialized_end=1108
  _globals['_CREATETABLERESPONSE']._serialized_start=1110
  _globals['_CREATETABLERESPONSE']._serialized_end=1186
  _globals['_GETTABLEREQUEST']._serialized_start=1188
  _globals['_GETTABLEREQUEST']._serialized_end=1279
  _globals['_GETTABLERESPONSE']._serialized_start=1281
  _globals['_GETTABLERESPONSE']._serialized_end=1354
  _globals['_UPDATETABLEREQUEST']._serialized_start=1357
  _globals['_UPDATETABLEREQUEST']._serialized_end=1567
  _globals['_UPDATETABLERESPONSE']._serialized_start=1569
  _globals['_UPDATETABLERESPONSE']._serialized_end=1645
  _globals['_DELETETABLEREQUEST']._serialized_start=1647
  _globals['_DELETETABLEREQUEST']._serialized_end=1741
  _globals['_DELETETABLERESPONSE']._serialized_start=1743
  _globals['_DELETETABLERESPONSE']._serialized_end=1764
  _globals['_NUMBERFORMAT']._serialized_start=1767
  _globals['_NUMBERFORMAT']._serialized_end=2053
  _globals['_NUMBERFORMAT_FORMAT']._serialized_start=1940
  _globals['_NUMBERFORMAT_FORMAT']._serialized_end=2053
  _globals['_COLUMNDEFINITION']._serialized_start=2056
  _globals['_COLUMNDEFINITION']._serialized_end=3432
  _globals['_COLUMNDEFINITION_AGENTCONFIG']._serialized_start=2579
  _globals['_COLUMNDEFINITION_AGENTCONFIG']._serialized_end=2930
  _globals['_COLUMNDEFINITION_AGENTCONFIG_CONTEXT']._serialized_start=2850
  _globals['_COLUMNDEFINITION_AGENTCONFIG_CONTEXT']._serialized_end=2897
  _globals['_COLUMNDEFINITION_SELECTION']._serialized_start=2933
  _globals['_COLUMNDEFINITION_SELECTION']._serialized_end=3351
  _globals['_COLUMNDEFINITION_SELECTION_OPTION']._serialized_start=3122
  _globals['_COLUMNDEFINITION_SELECTION_OPTION']._serialized_end=3250
  _globals['_COLUMNDEFINITION_SELECTION_SELECTIONTYPE']._serialized_start=3252
  _globals['_COLUMNDEFINITION_SELECTION_SELECTIONTYPE']._serialized_end=3351
  _globals['_COLUMNDEFINITION_SORT']._serialized_start=3353
  _globals['_COLUMNDEFINITION_SORT']._serialized_end=3422
  _globals['_GETCOLUMNDEFINITIONSREQUEST']._serialized_start=3434
  _globals['_GETCOLUMNDEFINITIONSREQUEST']._serialized_end=3537
  _globals['_GETCOLUMNDEFINITIONSRESPONSE']._serialized_start=3540
  _globals['_GETCOLUMNDEFINITIONSRESPONSE']._serialized_end=3805
  _globals['_GETCOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY']._serialized_start=3698
  _globals['_GETCOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY']._serialized_end=3805
  _globals['_UPDATECOLUMNDEFINITIONSREQUEST']._serialized_start=3808
  _globals['_UPDATECOLUMNDEFINITIONSREQUEST']._serialized_end=4146
  _globals['_UPDATECOLUMNDEFINITIONSREQUEST_COLUMNDEFINITIONSENTRY']._serialized_start=3698
  _globals['_UPDATECOLUMNDEFINITIONSREQUEST_COLUMNDEFINITIONSENTRY']._serialized_end=3805
  _globals['_UPDATECOLUMNDEFINITIONSRESPONSE']._serialized_start=4149
  _globals['_UPDATECOLUMNDEFINITIONSRESPONSE']._serialized_end=4420
  _globals['_UPDATECOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY']._serialized_start=3698
  _globals['_UPDATECOLUMNDEFINITIONSRESPONSE_COLUMNDEFINITIONSENTRY']._serialized_end=3805
  _globals['_GETCOLUMNDEFINITIONREQUEST']._serialized_start=4423
  _globals['_GETCOLUMNDEFINITIONREQUEST']._serialized_end=4561
  _globals['_GETCOLUMNDEFINITIONRESPONSE']._serialized_start=4563
  _globals['_GETCOLUMNDEFINITIONRESPONSE']._serialized_end=4681
  _globals['_RECOMPUTECOLUMNREQUEST']._serialized_start=4684
  _globals['_RECOMPUTECOLUMNREQUEST']._serialized_end=4818
  _globals['_RECOMPUTECOLUMNRESPONSE']._serialized_start=4820
  _globals['_RECOMPUTECOLUMNRESPONSE']._serialized_end=4845
  _globals['_CELL']._serialized_start=4848
  _globals['_CELL']._serialized_end=5824
  _globals['_CELL_TRANSPARENCY']._serialized_start=5776
  _globals['_CELL_TRANSPARENCY']._serialized_end=5815
  _globals['_NULLCELL']._serialized_start=5826
  _globals['_NULLCELL']._serialized_end=5836
  _globals['_STRINGCELL']._serialized_start=5839
  _globals['_STRINGCELL']._serialized_end=6004
  _globals['_NUMBERCELL']._serialized_start=6007
  _globals['_NUMBERCELL']._serialized_end=6172
  _globals['_BOOLEANCELL']._serialized_start=6175
  _globals['_BOOLEANCELL']._serialized_end=6341
  _globals['_FILECELL']._serialized_start=6344
  _globals['_FILECELL']._serialized_end=6584
  _globals['_DOCUMENTCELL']._serialized_start=6587
  _globals['_DOCUMENTCELL']._serialized_end=6763
  _globals['_ROW']._serialized_start=6766
  _globals['_ROW']._serialized_end=7102
  _globals['_ROW_CELLSENTRY']._serialized_start=7019
  _globals['_ROW_CELLSENTRY']._serialized_end=7102
  _globals['_LISTROWSREQUEST']._serialized_start=7105
  _globals['_LISTROWSREQUEST']._serialized_end=7278
  _globals['_LISTROWSRESPONSE']._serialized_start=7281
  _globals['_LISTROWSRESPONSE']._serialized_end=7431
  _globals['_INSERTROWREQUEST']._serialized_start=7434
  _globals['_INSERTROWREQUEST']._serialized_end=7637
  _globals['_INSERTROWRESPONSE']._serialized_start=7639
  _globals['_INSERTROWRESPONSE']._serialized_end=7707
  _globals['_UPDATEROWREQUEST']._serialized_start=7710
  _globals['_UPDATEROWREQUEST']._serialized_end=7876
  _globals['_UPDATEROWRESPONSE']._serialized_start=7878
  _globals['_UPDATEROWRESPONSE']._serialized_end=7946
  _globals['_GETROWREQUEST']._serialized_start=7948
  _globals['_GETROWREQUEST']._serialized_end=8067
  _globals['_GETROWRESPONSE']._serialized_start=8069
  _globals['_GETROWRESPONSE']._serialized_end=8134
  _globals['_UPDATEROWSREQUEST']._serialized_start=8137
  _globals['_UPDATEROWSREQUEST']._serialized_end=8276
  _globals['_UPDATEROWSRESPONSE']._serialized_start=8278
  _globals['_UPDATEROWSRESPONSE']._serialized_end=8349
  _globals['_DELETEROWREQUEST']._serialized_start=8351
  _globals['_DELETEROWREQUEST']._serialized_end=8473
  _globals['_DELETEROWRESPONSE']._serialized_start=8475
  _globals['_DELETEROWRESPONSE']._serialized_end=8494
  _globals['_DELETEROWSREQUEST']._serialized_start=8496
  _globals['_DELETEROWSREQUEST']._serialized_end=8621
  _globals['_DELETEROWSRESPONSE']._serialized_start=8623
  _globals['_DELETEROWSRESPONSE']._serialized_end=8643
  _globals['_MOVEROWSREQUEST']._serialized_start=8646
  _globals['_MOVEROWSREQUEST']._serialized_end=8836
  _globals['_MOVEROWSRESPONSE']._serialized_start=8838
  _globals['_MOVEROWSRESPONSE']._serialized_end=8856
  _globals['_GETCELLREQUEST']._serialized_start=8859
  _globals['_GETCELLREQUEST']._serialized_end=9011
  _globals['_GETCELLRESPONSE']._serialized_start=9013
  _globals['_GETCELLRESPONSE']._serialized_end=9082
  _globals['_UPDATECELLREQUEST']._serialized_start=9085
  _globals['_UPDATECELLREQUEST']._serialized_end=9287
  _globals['_UPDATECELLRESPONSE']._serialized_start=9289
  _globals['_UPDATECELLRESPONSE']._serialized_end=9361
  _globals['_RECOMPUTECELLREQUEST']._serialized_start=9364
  _globals['_RECOMPUTECELLREQUEST']._serialized_end=9522
  _globals['_RECOMPUTECELLRESPONSE']._serialized_start=9524
  _globals['_RECOMPUTECELLRESPONSE']._serialized_end=9599
  _globals['_RESETCELLREQUEST']._serialized_start=9602
  _globals['_RESETCELLREQUEST']._serialized_end=9756
  _globals['_RESETCELLRESPONSE']._serialized_start=9758
  _globals['_RESETCELLRESPONSE']._serialized_end=9829
  _globals['_LOCKCELLREQUEST']._serialized_start=9832
  _globals['_LOCKCELLREQUEST']._serialized_end=9985
  _globals['_LOCKCELLRESPONSE']._serialized_start=9987
  _globals['_LOCKCELLRESPONSE']._serialized_end=10057
  _globals['_UNLOCKCELLREQUEST']._serialized_start=10060
  _globals['_UNLOCKCELLREQUEST']._serialized_end=10215
  _globals['_UNLOCKCELLRESPONSE']._serialized_start=10217
  _globals['_UNLOCKCELLRESPONSE']._serialized_end=10289
  _globals['_EXPORTTABLEREQUEST']._serialized_start=10292
  _globals['_EXPORTTABLEREQUEST']._serialized_end=10450
  _globals['_EXPORTTABLERESPONSE']._serialized_start=10452
  _globals['_EXPORTTABLERESPONSE']._serialized_end=10498
  _globals['_GETTABLEEVENTSREQUEST']._serialized_start=10500
  _globals['_GETTABLEEVENTSREQUEST']._serialized_end=10597
  _globals['_GETTABLEEVENTSRESPONSE']._serialized_start=10599
  _globals['_GETTABLEEVENTSRESPONSE']._serialized_end=10683
  _globals['_TABLEEVENT']._serialized_start=10686
  _globals['_TABLEEVENT']._serialized_end=11484
  _globals['_TABLEUPDATEDEVENT']._serialized_start=11486
  _globals['_TABLEUPDATEDEVENT']._serialized_end=11560
  _globals['_TABLEDELETEDEVENT']._serialized_start=11562
  _globals['_TABLEDELETEDEVENT']._serialized_end=11581
  _globals['_COLUMNDEFINITIONSUPDATEDEVENT']._serialized_start=11584
  _globals['_COLUMNDEFINITIONSUPDATEDEVENT']._serialized_end=11851
  _globals['_COLUMNDEFINITIONSUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_start=3698
  _globals['_COLUMNDEFINITIONSUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_end=3805
  _globals['_ROWINSERTEDEVENT']._serialized_start=11853
  _globals['_ROWINSERTEDEVENT']._serialized_end=11963
  _globals['_ROWUPDATEDEVENT']._serialized_start=11965
  _globals['_ROWUPDATEDEVENT']._serialized_end=12031
  _globals['_ROWDELETEDEVENT']._serialized_start=12033
  _globals['_ROWDELETEDEVENT']._serialized_end=12080
  _globals['_ROWSMOVEDEVENT']._serialized_start=12082
  _globals['_ROWSMOVEDEVENT']._serialized_end=12197
  _globals['_CELLUPDATEDEVENT']._serialized_start=12199
  _globals['_CELLUPDATEDEVENT']._serialized_end=12305
  _globals['_GENERATEMOCKTABLEREQUEST']._serialized_start=12308
  _globals['_GENERATEMOCKTABLEREQUEST']._serialized_end=12679
  _globals['_GENERATEMOCKTABLEREQUEST_MODE']._serialized_start=12583
  _globals['_GENERATEMOCKTABLEREQUEST_MODE']._serialized_end=12642
  _globals['_GENERATEMOCKTABLERESPONSE']._serialized_start=12681
  _globals['_GENERATEMOCKTABLERESPONSE']._serialized_end=12708
  _globals['_BINDCHATTABLEREQUEST']._serialized_start=12711
  _globals['_BINDCHATTABLEREQUEST']._serialized_end=12839
  _globals['_BINDCHATTABLERESPONSE']._serialized_start=12841
  _globals['_BINDCHATTABLERESPONSE']._serialized_end=12864
  _globals['_UNBINDCHATTABLEREQUEST']._serialized_start=12867
  _globals['_UNBINDCHATTABLEREQUEST']._serialized_end=12997
  _globals['_UNBINDCHATTABLERESPONSE']._serialized_start=12999
  _globals['_UNBINDCHATTABLERESPONSE']._serialized_end=13024
  _globals['_LISTCHATTABLESREQUEST']._serialized_start=13026
  _globals['_LISTCHATTABLESREQUEST']._serialized_end=13121
  _globals['_LISTCHATTABLESRESPONSE']._serialized_start=13123
  _globals['_LISTCHATTABLESRESPONSE']._serialized_end=13204
# @@protoc_insertion_point(module_scope)
