# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n agent/agent/v1alpha/common.proto\x12\x13\x61gent.agent.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\"\x9a\x02\n\x08\x43itation\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32!.agent.agent.v1alpha.CitationTypeR\x04type\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03url\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x03url\x12\x1b\n\x06number\x18\x04 \x01(\rB\x03\xe0\x41\x03R\x06number\x12\"\n\x07summary\x18\x05 \x01(\tB\x03\xe0\x41\x03H\x00R\x07summary\x88\x01\x01\x12Z\n\x0e\x65xtract_method\x18\x06 \x01(\x0e\x32..agent.agent.v1alpha.CitationExtractMethodTypeB\x03\xe0\x41\x03R\rextractMethodB\n\n\x08_summary*u\n\x0c\x43itationType\x12\x1d\n\x19\x43ITATION_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43ITATION_TYPE_FILE\x10\x01\x12\x15\n\x11\x43ITATION_TYPE_WEB\x10\x02\x12\x17\n\x13\x43ITATION_TYPE_TABLE\x10\x03*\xec\x01\n\x19\x43itationExtractMethodType\x12,\n(CITATION_EXTRACT_METHOD_TYPE_UNSPECIFIED\x10\x00\x12%\n!CITATION_EXTRACT_METHOD_TYPE_SELF\x10\x01\x12$\n CITATION_EXTRACT_METHOD_TYPE_WEB\x10\x02\x12$\n CITATION_EXTRACT_METHOD_TYPE_RAG\x10\x03\x12.\n*CITATION_EXTRACT_METHOD_TYPE_DEEP_ANALYSIS\x10\x04\x42\xd8\x01\n\x17\x63om.agent.agent.v1alphaB\x0b\x43ommonProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\013CommonProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _CITATION.fields_by_name['name']._options = None
  _CITATION.fields_by_name['name']._serialized_options = b'\340A\003'
  _CITATION.fields_by_name['url']._options = None
  _CITATION.fields_by_name['url']._serialized_options = b'\340A\003'
  _CITATION.fields_by_name['number']._options = None
  _CITATION.fields_by_name['number']._serialized_options = b'\340A\003'
  _CITATION.fields_by_name['summary']._options = None
  _CITATION.fields_by_name['summary']._serialized_options = b'\340A\003'
  _CITATION.fields_by_name['extract_method']._options = None
  _CITATION.fields_by_name['extract_method']._serialized_options = b'\340A\003'
  _globals['_CITATIONTYPE']._serialized_start=375
  _globals['_CITATIONTYPE']._serialized_end=492
  _globals['_CITATIONEXTRACTMETHODTYPE']._serialized_start=495
  _globals['_CITATIONEXTRACTMETHODTYPE']._serialized_end=731
  _globals['_CITATION']._serialized_start=91
  _globals['_CITATION']._serialized_end=373
# @@protoc_insertion_point(module_scope)
