# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline/pipeline/v1beta/integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pipeline.pipeline.v1beta import common_pb2 as pipeline_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*pipeline/pipeline/v1beta/integration.proto\x12\x18pipeline.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%pipeline/pipeline/v1beta/common.proto\"\x87\x06\n\nConnection\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x02id\x12&\n\x0cnamespace_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0bnamespaceId\x12-\n\x0eintegration_id\x18\x04 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05R\rintegrationId\x12\x30\n\x11integration_title\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x10integrationTitle\x12H\n\x06method\x18\x06 \x01(\x0e\x32+.pipeline.pipeline.v1beta.Connection.MethodB\x03\xe0\x41\x02R\x06method\x12\x32\n\x05setup\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x02R\x05setup\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x01R\x06scopes\x12$\n\x08identity\x18\r \x01(\tB\x03\xe0\x41\x01H\x00R\x08identity\x88\x01\x01\x12T\n\x15o_auth_access_details\x18\x0c \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x01H\x01R\x12oAuthAccessDetails\x88\x01\x01\x12\x37\n\x04view\x18\x08 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x12@\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\"I\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x15\n\x11METHOD_DICTIONARY\x10\x01\x12\x10\n\x0cMETHOD_OAUTH\x10\x02\x42\x0b\n\t_identityB\x18\n\x16_o_auth_access_details\"\xe3\x01\n\x1fListNamespaceConnectionsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12%\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xc0\x01\n ListNamespaceConnectionsResponse\x12K\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\x0b\x63onnections\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb8\x01\n\x1dGetNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12<\n\x04view\x18\x03 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"k\n\x1eGetNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"\x95\x01\n CreateNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\"n\n!CreateNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"\x81\x02\n UpdateNamespaceConnectionRequest\x12(\n\rconnection_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12&\n\x0cnamespace_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12I\n\nconnection\x18\x02 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x02R\nconnection\x12@\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\"n\n!UpdateNamespaceConnectionResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnection\"t\n DeleteNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"#\n!DeleteNamespaceConnectionResponse\"r\n\x1eTestNamespaceConnectionRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\"!\n\x1fTestNamespaceConnectionResponse\"\xa7\x05\n\x0bIntegration\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x19\n\x05title\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x1b\n\x06vendor\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x06vendor\x12\x17\n\x04icon\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x04icon\x12Q\n\thelp_link\x18\x07 \x01(\x0b\x32*.pipeline.pipeline.v1beta.Integration.LinkB\x03\xe0\x41\x03H\x00R\x08helpLink\x88\x01\x01\x12?\n\x0csetup_schema\x18\n \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0bsetupSchema\x12_\n\ro_auth_config\x18\x0b \x01(\x0b\x32\x31.pipeline.pipeline.v1beta.Integration.OAuthConfigB\x03\xe0\x41\x03H\x01R\x0boAuthConfig\x88\x01\x01\x12\x37\n\x04view\x18\t \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x03R\x04view\x1a\x36\n\x04Link\x12\x17\n\x04text\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04text\x12\x15\n\x03url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03url\x1an\n\x0bOAuthConfig\x12\x1e\n\x08\x61uth_url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07\x61uthUrl\x12\"\n\naccess_url\x18\x02 \x01(\tB\x03\xe0\x41\x03R\taccessUrl\x12\x1b\n\x06scopes\x18\x0b \x03(\tB\x03\xe0\x41\x03R\x06scopesB\x0c\n\n_help_linkB\x10\n\x0e_o_auth_config\"\x92\x02\n$ListPipelineIDsByConnectionIDRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12(\n\rconnection_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0c\x63onnectionId\x12%\n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xa0\x01\n%ListPipelineIDsByConnectionIDResponse\x12&\n\x0cpipeline_ids\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x0bpipelineIds\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xb3\x01\n\x17ListIntegrationsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12\'\n\npage_token\x18\x02 \x01(\tB\x03\xe0\x41\x01H\x01R\tpageToken\x88\x01\x01\x12 \n\x06\x66ilter\x18\x03 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xbb\x01\n\x18ListIntegrationsResponse\x12N\n\x0cintegrations\x18\x01 \x03(\x0b\x32%.pipeline.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0cintegrations\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\x8a\x01\n\x15GetIntegrationRequest\x12*\n\x0eintegration_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rintegrationId\x12<\n\x04view\x18\x02 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"f\n\x16GetIntegrationResponse\x12L\n\x0bintegration\x18\x01 \x01(\x0b\x32%.pipeline.pipeline.v1beta.IntegrationB\x03\xe0\x41\x03R\x0bintegration\"|\n\x1cLookUpConnectionAdminRequest\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03uid\x12<\n\x04view\x18\x02 \x01(\x0e\x32\x1e.pipeline.pipeline.v1beta.ViewB\x03\xe0\x41\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_view\"j\n\x1dLookUpConnectionAdminResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32$.pipeline.pipeline.v1beta.ConnectionB\x03\xe0\x41\x03R\nconnectionB\xfd\x01\n\x1c\x63om.pipeline.pipeline.v1betaB\x10IntegrationProtoP\x01ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\xa2\x02\x03PPX\xaa\x02\x18Pipeline.Pipeline.V1beta\xca\x02\x18Pipeline\\Pipeline\\V1beta\xe2\x02$Pipeline\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x1aPipeline::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline.pipeline.v1beta.integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.pipeline.pipeline.v1betaB\020IntegrationProtoP\001ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\242\002\003PPX\252\002\030Pipeline.Pipeline.V1beta\312\002\030Pipeline\\Pipeline\\V1beta\342\002$Pipeline\\Pipeline\\V1beta\\GPBMetadata\352\002\032Pipeline::Pipeline::V1beta'
  _CONNECTION.fields_by_name['uid']._options = None
  _CONNECTION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['id']._options = None
  _CONNECTION.fields_by_name['id']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['namespace_id']._options = None
  _CONNECTION.fields_by_name['namespace_id']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['integration_id']._options = None
  _CONNECTION.fields_by_name['integration_id']._serialized_options = b'\340A\002\340A\005'
  _CONNECTION.fields_by_name['integration_title']._options = None
  _CONNECTION.fields_by_name['integration_title']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['method']._options = None
  _CONNECTION.fields_by_name['method']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['setup']._options = None
  _CONNECTION.fields_by_name['setup']._serialized_options = b'\340A\002'
  _CONNECTION.fields_by_name['scopes']._options = None
  _CONNECTION.fields_by_name['scopes']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['identity']._options = None
  _CONNECTION.fields_by_name['identity']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['o_auth_access_details']._options = None
  _CONNECTION.fields_by_name['o_auth_access_details']._serialized_options = b'\340A\001'
  _CONNECTION.fields_by_name['view']._options = None
  _CONNECTION.fields_by_name['view']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['create_time']._options = None
  _CONNECTION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CONNECTION.fields_by_name['update_time']._options = None
  _CONNECTION.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._options = None
  _LISTNAMESPACECONNECTIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['connections']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTNAMESPACECONNECTIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._options = None
  _GETNAMESPACECONNECTIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _GETNAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _CREATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['connection']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._options = None
  _UPDATENAMESPACECONNECTIONREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._options = None
  _UPDATENAMESPACECONNECTIONRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETENAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _TESTNAMESPACECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _INTEGRATION_LINK.fields_by_name['text']._options = None
  _INTEGRATION_LINK.fields_by_name['text']._serialized_options = b'\340A\003'
  _INTEGRATION_LINK.fields_by_name['url']._options = None
  _INTEGRATION_LINK.fields_by_name['url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['auth_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['access_url']._serialized_options = b'\340A\003'
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._options = None
  _INTEGRATION_OAUTHCONFIG.fields_by_name['scopes']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['uid']._options = None
  _INTEGRATION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['id']._options = None
  _INTEGRATION.fields_by_name['id']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['title']._options = None
  _INTEGRATION.fields_by_name['title']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['description']._options = None
  _INTEGRATION.fields_by_name['description']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['vendor']._options = None
  _INTEGRATION.fields_by_name['vendor']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['icon']._options = None
  _INTEGRATION.fields_by_name['icon']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['help_link']._options = None
  _INTEGRATION.fields_by_name['help_link']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['setup_schema']._options = None
  _INTEGRATION.fields_by_name['setup_schema']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['o_auth_config']._options = None
  _INTEGRATION.fields_by_name['o_auth_config']._serialized_options = b'\340A\003'
  _INTEGRATION.fields_by_name['view']._options = None
  _INTEGRATION.fields_by_name['view']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['connection_id']._serialized_options = b'\340A\002'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['pipeline_ids']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._options = None
  _LISTPIPELINEIDSBYCONNECTIONIDRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINTEGRATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['integrations']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTINTEGRATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['integration_id']._serialized_options = b'\340A\002'
  _GETINTEGRATIONREQUEST.fields_by_name['view']._options = None
  _GETINTEGRATIONREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._options = None
  _GETINTEGRATIONRESPONSE.fields_by_name['integration']._serialized_options = b'\340A\003'
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['uid']._options = None
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['uid']._serialized_options = b'\340A\002'
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['view']._options = None
  _LOOKUPCONNECTIONADMINREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LOOKUPCONNECTIONADMINRESPONSE.fields_by_name['connection']._options = None
  _LOOKUPCONNECTIONADMINRESPONSE.fields_by_name['connection']._serialized_options = b'\340A\003'
  _globals['_CONNECTION']._serialized_start=242
  _globals['_CONNECTION']._serialized_end=1017
  _globals['_CONNECTION_METHOD']._serialized_start=905
  _globals['_CONNECTION_METHOD']._serialized_end=978
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_start=1020
  _globals['_LISTNAMESPACECONNECTIONSREQUEST']._serialized_end=1247
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_start=1250
  _globals['_LISTNAMESPACECONNECTIONSRESPONSE']._serialized_end=1442
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_start=1445
  _globals['_GETNAMESPACECONNECTIONREQUEST']._serialized_end=1629
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_start=1631
  _globals['_GETNAMESPACECONNECTIONRESPONSE']._serialized_end=1738
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_start=1741
  _globals['_CREATENAMESPACECONNECTIONREQUEST']._serialized_end=1890
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_start=1892
  _globals['_CREATENAMESPACECONNECTIONRESPONSE']._serialized_end=2002
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_start=2005
  _globals['_UPDATENAMESPACECONNECTIONREQUEST']._serialized_end=2262
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_start=2264
  _globals['_UPDATENAMESPACECONNECTIONRESPONSE']._serialized_end=2374
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_start=2376
  _globals['_DELETENAMESPACECONNECTIONREQUEST']._serialized_end=2492
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_start=2494
  _globals['_DELETENAMESPACECONNECTIONRESPONSE']._serialized_end=2529
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_start=2531
  _globals['_TESTNAMESPACECONNECTIONREQUEST']._serialized_end=2645
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_start=2647
  _globals['_TESTNAMESPACECONNECTIONRESPONSE']._serialized_end=2680
  _globals['_INTEGRATION']._serialized_start=2683
  _globals['_INTEGRATION']._serialized_end=3362
  _globals['_INTEGRATION_LINK']._serialized_start=3164
  _globals['_INTEGRATION_LINK']._serialized_end=3218
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_start=3220
  _globals['_INTEGRATION_OAUTHCONFIG']._serialized_end=3330
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_start=3365
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDREQUEST']._serialized_end=3639
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_start=3642
  _globals['_LISTPIPELINEIDSBYCONNECTIONIDRESPONSE']._serialized_end=3802
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_start=3805
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_end=3984
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=3987
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=4174
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=4177
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=4315
  _globals['_GETINTEGRATIONRESPONSE']._serialized_start=4317
  _globals['_GETINTEGRATIONRESPONSE']._serialized_end=4419
  _globals['_LOOKUPCONNECTIONADMINREQUEST']._serialized_start=4421
  _globals['_LOOKUPCONNECTIONADMINREQUEST']._serialized_end=4545
  _globals['_LOOKUPCONNECTIONADMINRESPONSE']._serialized_start=4547
  _globals['_LOOKUPCONNECTIONADMINRESPONSE']._serialized_end=4653
# @@protoc_insertion_point(module_scope)
