# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openapi/v2/conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15openapi/v2/conf.proto\x12\nopenapi.v2\x1a.protoc-gen-openapiv2/options/annotations.protoB\xaf\t\n\x0e\x63om.openapi.v2B\tConfProtoP\x01Z6github.com/instill-ai/protogen-go/openapi/v2;openapiv2\xa2\x02\x03OXX\xaa\x02\nOpenapi.V2\xca\x02\nOpenapi\\V2\xe2\x02\x16Openapi\\V2\\GPBMetadata\xea\x02\x0bOpenapi::V2\x92\x41\x8f\x08\x12\xee\x01\n\x13\xf0\x9f\x94\xae Instill AI API\x12/Interact with Instill AI through its public API\"?\n\nInstill AI\x12\x1dhttps://github.com/instill-ai\x1a\x12hello@instill.tech*W\n\x1a\x45lastic License 2.0 (ELv2)\x12\x39https://github.com/instill-ai/protobufs/blob/main/LICENSE2\x0cv0.50.4-beta\x1a\x12\x61pi.instill-ai.com*\x02\x02\x01\x32\x10\x61pplication/json:\x10\x61pplication/jsonR<\n\x03\x34\x30\x31\x12\x35\n3Returned when the client credentials are not valid.Z\x8b\x01\n\x88\x01\n\x06\x42\x65\x61rer\x12~\x08\x02\x12\x43\x45nter the token with the `Bearer ` prefix, e.g. `Bearer abcde12345`\x1a\rAuthorization \x02J$\n\tx-default\x12\x17\x1a\x15\x42\x65\x61rer instill_sk_***b\x0c\n\n\n\x06\x42\x65\x61rer\x12\x00j]\n\x0e\xf0\x9f\xaa\x86 Namespace\x12KNamespaces (e.g. User, Organization) that structure the resource hierarchy.j8\n\r\xf0\x9f\x92\xa7 Pipeline\x12\'Pipeline orchestration in Instill Core.j4\n\x0c\xe2\x9a\x97\xef\xb8\x8f Model\x12$AI Model resources for MLOps/LLMOps.jQ\n\r\xf0\x9f\x92\xbe Artifact\x12@Data orchestration for unified unstructured data representation.j%\n\n\xf0\x9f\x8d\x8e Agent\x12\x17Ready-to-use AI agents.j$\n\x05Table\x12\x1bTable resources for agents.j\'\n\x0c\xf0\x9f\x93\x8a Metrics\x12\x17Resource usage metrics.j4\n\x11\xf0\x9f\xa4\x9d Subscription\x12\x1fPricing plans on Instill Cloud.r8\n\x15More about Instill AI\x12\x1fhttps://www.instill-ai.dev/docsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'openapi.v2.conf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.openapi.v2B\tConfProtoP\001Z6github.com/instill-ai/protogen-go/openapi/v2;openapiv2\242\002\003OXX\252\002\nOpenapi.V2\312\002\nOpenapi\\V2\342\002\026Openapi\\V2\\GPBMetadata\352\002\013Openapi::V2\222A\217\010\022\356\001\n\023\360\237\224\256 Instill AI API\022/Interact with Instill AI through its public API\"?\n\nInstill AI\022\035https://github.com/instill-ai\032\022hello@instill.tech*W\n\032Elastic License 2.0 (ELv2)\0229https://github.com/instill-ai/protobufs/blob/main/LICENSE2\014v0.50.4-beta\032\022api.instill-ai.com*\002\002\0012\020application/json:\020application/jsonR<\n\003401\0225\n3Returned when the client credentials are not valid.Z\213\001\n\210\001\n\006Bearer\022~\010\002\022CEnter the token with the `Bearer ` prefix, e.g. `Bearer abcde12345`\032\rAuthorization \002J$\n\tx-default\022\027\032\025Bearer instill_sk_***b\014\n\n\n\006Bearer\022\000j]\n\016\360\237\252\206 Namespace\022KNamespaces (e.g. User, Organization) that structure the resource hierarchy.j8\n\r\360\237\222\247 Pipeline\022\'Pipeline orchestration in Instill Core.j4\n\014\342\232\227\357\270\217 Model\022$AI Model resources for MLOps/LLMOps.jQ\n\r\360\237\222\276 Artifact\022@Data orchestration for unified unstructured data representation.j%\n\n\360\237\215\216 Agent\022\027Ready-to-use AI agents.j$\n\005Table\022\033Table resources for agents.j\'\n\014\360\237\223\212 Metrics\022\027Resource usage metrics.j4\n\021\360\237\244\235 Subscription\022\037Pricing plans on Instill Cloud.r8\n\025More about Instill AI\022\037https://www.instill-ai.dev/docs'
# @@protoc_insertion_point(module_scope)
