# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/chat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent.agent.v1alpha import common_pb2 as agent_dot_agent_dot_v1alpha_dot_common__pb2
from agent.agent.v1alpha import table_pb2 as agent_dot_agent_dot_v1alpha_dot_table__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61gent/agent/v1alpha/chat.proto\x12\x13\x61gent.agent.v1alpha\x1a agent/agent/v1alpha/common.proto\x1a\x1f\x61gent/agent/v1alpha/table.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd0\x01\n\x0b\x41gentConfig\x12\'\n\x0cinstructions\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x0cinstructions\x12X\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32\x31.agent.agent.v1alpha.AgentConfig.ConnectionsEntryB\x03\xe0\x41\x01R\x0b\x63onnections\x1a>\n\x10\x43onnectionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xac\x03\n\x04\x43hat\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12/\n\x11\x63hat_display_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x04 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x03R\x0b\x61gentConfig\x12@\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12@\n\x0b\x64\x65lete_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ndeleteTime\x12$\n\ncatalog_id\x18\x08 \x01(\tB\x05\x18\x01\xe0\x41\x03R\tcatalogId\"\xaf\x05\n\x07Message\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x07\x63hatUid\x12\x1d\n\x07\x63ontent\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07\x63ontent\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\x12\x41\n\x04type\x18\x05 \x01(\x0e\x32(.agent.agent.v1alpha.Message.MessageTypeB\x03\xe0\x41\x02R\x04type\x12@\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12)\n\x0emsg_sender_uid\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\x12@\n\tcitations\x18\t \x03(\x0b\x32\x1d.agent.agent.v1alpha.CitationB\x03\xe0\x41\x03R\tcitations\x12?\n\x07\x63ontext\x18\n \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x03R\x07\x63ontext\x12K\n\x0b\x61ttachments\x18\x0b \x01(\x0b\x32$.agent.agent.v1alpha.ChatAttachmentsB\x03\xe0\x41\x03R\x0b\x61ttachments\x12/\n\x11\x65nable_web_search\x18\x0c \x01(\x08\x42\x03\xe0\x41\x03R\x0f\x65nableWebSearch\"B\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MESSAGE_TYPE_TEXT\x10\x01\"1\n\x0b\x43hatContext\x12\"\n\ntable_uids\x18\x01 \x03(\tB\x03\xe0\x41\x01R\ttableUids\"3\n\x0f\x43hatAttachments\x12 \n\tfile_urls\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x08\x66ileUrls\"\xdc\x01\n\x11\x43reateChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12/\n\x11\x63hat_display_name\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x03 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x01R\x0b\x61gentConfig\x12$\n\ncatalog_id\x18\x04 \x01(\tB\x05\x18\x01\xe0\x41\x01R\tcatalogId\"H\n\x12\x43reateChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"\xbc\x01\n\x10ListChatsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12\"\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01R\tpageToken\x12\x1a\n\x06if_all\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\x12\x1e\n\x08\x63hat_uid\x18\x05 \x01(\tB\x03\xe0\x41\x01R\x07\x63hatUid\"\x9a\x01\n\x11ListChatsResponse\x12\x34\n\x05\x63hats\x18\x01 \x03(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x05\x63hats\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xd1\x01\n\x11UpdateChatRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12/\n\x11\x63hat_display_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x04 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x01R\x0b\x61gentConfig\"H\n\x12UpdateChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"X\n\x0eGetChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\"E\n\x0fGetChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"[\n\x11\x44\x65leteChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\"\x14\n\x12\x44\x65leteChatResponse\"\xd5\x01\n\x14MessageSenderProfile\x12)\n\x0emsg_sender_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\x12\'\n\rmsg_sender_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0bmsgSenderId\x12+\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x03H\x00R\x0b\x64isplayName\x88\x01\x01\x12 \n\x06\x61vatar\x18\x04 \x01(\tB\x03\xe0\x41\x03H\x01R\x06\x61vatar\x88\x01\x01\x42\x0f\n\r_display_nameB\t\n\x07_avatar\"\xbf\x01\n\x13ListMessagesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\"\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tpageToken\x12\x1a\n\x06if_all\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\"\xff\x01\n\x14ListMessagesResponse\x12=\n\x08messages\x18\x01 \x03(\x0b\x32\x1c.agent.agent.v1alpha.MessageB\x03\xe0\x41\x03R\x08messages\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12W\n\x0fsender_profiles\x18\x04 \x03(\x0b\x32).agent.agent.v1alpha.MessageSenderProfileB\x03\xe0\x41\x03R\x0esenderProfiles\"\xb9\x02\n\x14\x43hatWithAgentRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07message\x12\"\n\tfile_uids\x18\x04 \x03(\tB\x05\x18\x01\xe0\x41\x01R\x08\x66ileUids\x12/\n\x11\x65nable_web_search\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x0f\x65nableWebSearch\x12$\n\x0bobject_uids\x18\x06 \x03(\tB\x03\xe0\x41\x01R\nobjectUids\x12?\n\x07\x63ontext\x18\x07 \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x01R\x07\x63ontext\"O\n\x15\x43hatWithAgentResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\"9\n\x18TableBuilderAgentMessage\x12\x1d\n\x07message\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07message\"\xd2\x01\n$ListTableBuilderAgentMessagesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\"\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tpageToken\x12\x1a\n\x06if_all\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\"\x90\x02\n%ListTableBuilderAgentMessagesResponse\x12=\n\x08messages\x18\x01 \x03(\x0b\x32\x1c.agent.agent.v1alpha.MessageB\x03\xe0\x41\x03R\x08messages\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12W\n\x0fsender_profiles\x18\x04 \x03(\x0b\x32).agent.agent.v1alpha.MessageSenderProfileB\x03\xe0\x41\x03R\x0esenderProfiles\"\x8b\x01\n ChatWithTableBuilderAgentRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07message\"^\n!ChatWithTableBuilderAgentResponse\x12\x39\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.agent.agent.v1alpha.ChatEventB\x03\xe0\x41\x03R\x05\x65vent\"\xa5\x0b\n\tChatEvent\x12\x19\n\x05\x65vent\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x05\x65vent\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12U\n\x12\x63hat_started_event\x18\x03 \x01(\x0b\x32%.agent.agent.v1alpha.ChatStartedEventH\x00R\x10\x63hatStartedEvent\x12h\n\x19\x63hat_status_updated_event\x18\x04 \x01(\x0b\x32+.agent.agent.v1alpha.ChatStatusUpdatedEventH\x00R\x16\x63hatStatusUpdatedEvent\x12h\n\x19\x63hat_output_updated_event\x18\x05 \x01(\x0b\x32+.agent.agent.v1alpha.ChatOutputUpdatedEventH\x00R\x16\x63hatOutputUpdatedEvent\x12\x62\n\x17\x63hat_name_updated_event\x18\x06 \x01(\x0b\x32).agent.agent.v1alpha.ChatNameUpdatedEventH\x00R\x14\x63hatNameUpdatedEvent\x12n\n\x1b\x63hat_replan_triggered_event\x18\x07 \x01(\x0b\x32-.agent.agent.v1alpha.ChatReplanTriggeredEventH\x00R\x18\x63hatReplanTriggeredEvent\x12{\n chat_citation_list_updated_event\x18\x08 \x01(\x0b\x32\x31.agent.agent.v1alpha.ChatCitationListUpdatedEventH\x00R\x1c\x63hatCitationListUpdatedEvent\x12\x65\n\x18\x63hat_table_created_event\x18\t \x01(\x0b\x32*.agent.agent.v1alpha.ChatTableCreatedEventH\x00R\x15\x63hatTableCreatedEvent\x12\x65\n\x18\x63hat_error_updated_event\x18\n \x01(\x0b\x32*.agent.agent.v1alpha.ChatErrorUpdatedEventH\x00R\x15\x63hatErrorUpdatedEvent\x12x\n\x1f\x63hat_debug_output_updated_event\x18\x0b \x01(\x0b\x32\x30.agent.agent.v1alpha.ChatDebugOutputUpdatedEventH\x00R\x1b\x63hatDebugOutputUpdatedEvent\x12O\n\x10\x63hat_ended_event\x18\x0c \x01(\x0b\x32#.agent.agent.v1alpha.ChatEndedEventH\x00R\x0e\x63hatEndedEvent\x12w\n\x1e\x63hat_attachments_updated_event\x18\r \x01(\x0b\x32\x30.agent.agent.v1alpha.ChatAttachmentsUpdatedEventH\x00R\x1b\x63hatAttachmentsUpdatedEvent\x12k\n\x1a\x63hat_context_updated_event\x18\x0e \x01(\x0b\x32,.agent.agent.v1alpha.ChatContextUpdatedEventH\x00R\x17\x63hatContextUpdatedEvent\x12\x65\n\x18\x63hat_table_updated_event\x18\x0f \x01(\x0b\x32*.agent.agent.v1alpha.ChatTableUpdatedEventH\x00R\x15\x63hatTableUpdatedEventB\x06\n\x04\x64\x61ta\"T\n\x10\x43hatStartedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\"\x80\x01\n\x16\x43hatStatusUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12$\n\x0b\x63hat_status\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nchatStatus\"\x90\x01\n\x16\x43hatOutputUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x34\n\x12output_chunk_delta\x18\x02 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x02R\x10outputChunkDelta\"q\n\x14\x43hatNameUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x04name\"\x8b\x01\n\x18\x43hatReplanTriggeredEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12-\n\x10number_of_replan\x18\x02 \x01(\rB\x03\xe0\x41\x03R\x0enumberOfReplan\"\xa5\x01\n\x1c\x43hatCitationListUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x43\n\tcitations\x18\x02 \x03(\x0b\x32\x1d.agent.agent.v1alpha.CitationB\x06\xe0\x41\x03\xe0\x41\x02R\tcitations\"\xac\x01\n\x1b\x43hatAttachmentsUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12K\n\x0b\x61ttachments\x18\x02 \x01(\x0b\x32$.agent.agent.v1alpha.ChatAttachmentsB\x03\xe0\x41\x03R\x0b\x61ttachments\"\x9c\x01\n\x17\x43hatContextUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12?\n\x07\x63ontext\x18\x02 \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x03R\x07\x63ontext\"\x96\x03\n\x15\x43hatTableCreatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08tableUid\x12\x35\n\x05table\x18\x03 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\x12u\n\x12\x63olumn_definitions\x18\x04 \x03(\x0b\x32\x41.agent.agent.v1alpha.ChatTableCreatedEvent.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x96\x03\n\x15\x43hatTableUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08tableUid\x12\x35\n\x05table\x18\x03 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\x12u\n\x12\x63olumn_definitions\x18\x04 \x03(\x0b\x32\x41.agent.agent.v1alpha.ChatTableUpdatedEvent.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x98\x01\n\x15\x43hatErrorUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\"\n\nerror_type\x18\x02 \x01(\tB\x03\xe0\x41\x03R\terrorType\x12\x19\n\x05\x65rror\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x05\x65rror\"\x87\x01\n\x1b\x43hatDebugOutputUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12&\n\x0c\x64\x65\x62ug_output\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65\x62ugOutput\"R\n\x0e\x43hatEndedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTimeB\xd6\x01\n\x17\x63om.agent.agent.v1alphaB\tChatProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.chat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\tChatProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _AGENTCONFIG_CONNECTIONSENTRY._options = None
  _AGENTCONFIG_CONNECTIONSENTRY._serialized_options = b'8\001'
  _AGENTCONFIG.fields_by_name['instructions']._options = None
  _AGENTCONFIG.fields_by_name['instructions']._serialized_options = b'\340A\001'
  _AGENTCONFIG.fields_by_name['connections']._options = None
  _AGENTCONFIG.fields_by_name['connections']._serialized_options = b'\340A\001'
  _CHAT.fields_by_name['uid']._options = None
  _CHAT.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['namespace_id']._options = None
  _CHAT.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHAT.fields_by_name['chat_display_name']._options = None
  _CHAT.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _CHAT.fields_by_name['agent_config']._options = None
  _CHAT.fields_by_name['agent_config']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['create_time']._options = None
  _CHAT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['update_time']._options = None
  _CHAT.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['delete_time']._options = None
  _CHAT.fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['catalog_id']._options = None
  _CHAT.fields_by_name['catalog_id']._serialized_options = b'\030\001\340A\003'
  _MESSAGE.fields_by_name['uid']._options = None
  _MESSAGE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['chat_uid']._options = None
  _MESSAGE.fields_by_name['chat_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['content']._options = None
  _MESSAGE.fields_by_name['content']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['role']._options = None
  _MESSAGE.fields_by_name['role']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['type']._options = None
  _MESSAGE.fields_by_name['type']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['create_time']._options = None
  _MESSAGE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['update_time']._options = None
  _MESSAGE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['citations']._options = None
  _MESSAGE.fields_by_name['citations']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['context']._options = None
  _MESSAGE.fields_by_name['context']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['attachments']._options = None
  _MESSAGE.fields_by_name['attachments']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['enable_web_search']._options = None
  _MESSAGE.fields_by_name['enable_web_search']._serialized_options = b'\340A\003'
  _CHATCONTEXT.fields_by_name['table_uids']._options = None
  _CHATCONTEXT.fields_by_name['table_uids']._serialized_options = b'\340A\001'
  _CHATATTACHMENTS.fields_by_name['file_urls']._options = None
  _CHATATTACHMENTS.fields_by_name['file_urls']._serialized_options = b'\340A\003'
  _CREATECHATREQUEST.fields_by_name['namespace_id']._options = None
  _CREATECHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATECHATREQUEST.fields_by_name['chat_display_name']._options = None
  _CREATECHATREQUEST.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _CREATECHATREQUEST.fields_by_name['agent_config']._options = None
  _CREATECHATREQUEST.fields_by_name['agent_config']._serialized_options = b'\340A\001'
  _CREATECHATREQUEST.fields_by_name['catalog_id']._options = None
  _CREATECHATREQUEST.fields_by_name['catalog_id']._serialized_options = b'\030\001\340A\001'
  _CREATECHATRESPONSE.fields_by_name['chat']._options = None
  _CREATECHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _LISTCHATSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCHATSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTCHATSREQUEST.fields_by_name['page_size']._options = None
  _LISTCHATSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['page_token']._options = None
  _LISTCHATSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['if_all']._options = None
  _LISTCHATSREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['chat_uid']._options = None
  _LISTCHATSREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\001'
  _LISTCHATSRESPONSE.fields_by_name['chats']._options = None
  _LISTCHATSRESPONSE.fields_by_name['chats']._serialized_options = b'\340A\003'
  _LISTCHATSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTCHATSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTCHATSRESPONSE.fields_by_name['total_size']._options = None
  _LISTCHATSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _UPDATECHATREQUEST.fields_by_name['chat_uid']._options = None
  _UPDATECHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _UPDATECHATREQUEST.fields_by_name['chat_display_name']._options = None
  _UPDATECHATREQUEST.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _UPDATECHATREQUEST.fields_by_name['agent_config']._options = None
  _UPDATECHATREQUEST.fields_by_name['agent_config']._serialized_options = b'\340A\001'
  _UPDATECHATRESPONSE.fields_by_name['chat']._options = None
  _UPDATECHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _GETCHATREQUEST.fields_by_name['namespace_id']._options = None
  _GETCHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETCHATREQUEST.fields_by_name['chat_uid']._options = None
  _GETCHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _GETCHATRESPONSE.fields_by_name['chat']._options = None
  _GETCHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _DELETECHATREQUEST.fields_by_name['namespace_id']._options = None
  _DELETECHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETECHATREQUEST.fields_by_name['chat_uid']._options = None
  _DELETECHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['chat_uid']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._serialized_options = b'\340A\003'
  _CHATWITHAGENTREQUEST.fields_by_name['namespace_id']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['chat_uid']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['message']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['message']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['file_uids']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['file_uids']._serialized_options = b'\030\001\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['enable_web_search']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['enable_web_search']._serialized_options = b'\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['object_uids']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['object_uids']._serialized_options = b'\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['context']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['context']._serialized_options = b'\340A\001'
  _CHATWITHAGENTRESPONSE.fields_by_name['outputs']._options = None
  _CHATWITHAGENTRESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TABLEBUILDERAGENTMESSAGE.fields_by_name['message']._options = None
  _TABLEBUILDERAGENTMESSAGE.fields_by_name['message']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['table_uid']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['if_all']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['messages']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['messages']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['total_size']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['sender_profiles']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['sender_profiles']._serialized_options = b'\340A\003'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['namespace_id']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['table_uid']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['message']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['message']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTRESPONSE.fields_by_name['event']._options = None
  _CHATWITHTABLEBUILDERAGENTRESPONSE.fields_by_name['event']._serialized_options = b'\340A\003'
  _CHATEVENT.fields_by_name['event']._options = None
  _CHATEVENT.fields_by_name['event']._serialized_options = b'\340A\003'
  _CHATEVENT.fields_by_name['id']._options = None
  _CHATEVENT.fields_by_name['id']._serialized_options = b'\340A\003'
  _CHATSTARTEDEVENT.fields_by_name['create_time']._options = None
  _CHATSTARTEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATSTATUSUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATSTATUSUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATSTATUSUPDATEDEVENT.fields_by_name['chat_status']._options = None
  _CHATSTATUSUPDATEDEVENT.fields_by_name['chat_status']._serialized_options = b'\340A\003'
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['output_chunk_delta']._options = None
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['output_chunk_delta']._serialized_options = b'\340A\003\340A\002'
  _CHATNAMEUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATNAMEUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATNAMEUPDATEDEVENT.fields_by_name['name']._options = None
  _CHATNAMEUPDATEDEVENT.fields_by_name['name']._serialized_options = b'\340A\003'
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['create_time']._options = None
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['number_of_replan']._options = None
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['number_of_replan']._serialized_options = b'\340A\003'
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['citations']._options = None
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['citations']._serialized_options = b'\340A\003\340A\002'
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['attachments']._options = None
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['attachments']._serialized_options = b'\340A\003'
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['context']._options = None
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['context']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY._options = None
  _CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _CHATTABLECREATEDEVENT.fields_by_name['create_time']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['table_uid']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['table_uid']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['table']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['table']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['column_definitions']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY._options = None
  _CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _CHATTABLEUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['table_uid']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['table_uid']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['table']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['table']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['column_definitions']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['error_type']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['error_type']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['error']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['error']._serialized_options = b'\340A\003'
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['debug_output']._options = None
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['debug_output']._serialized_options = b'\340A\003'
  _CHATENDEDEVENT.fields_by_name['create_time']._options = None
  _CHATENDEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _globals['_AGENTCONFIG']._serialized_start=219
  _globals['_AGENTCONFIG']._serialized_end=427
  _globals['_AGENTCONFIG_CONNECTIONSENTRY']._serialized_start=365
  _globals['_AGENTCONFIG_CONNECTIONSENTRY']._serialized_end=427
  _globals['_CHAT']._serialized_start=430
  _globals['_CHAT']._serialized_end=858
  _globals['_MESSAGE']._serialized_start=861
  _globals['_MESSAGE']._serialized_end=1548
  _globals['_MESSAGE_MESSAGETYPE']._serialized_start=1482
  _globals['_MESSAGE_MESSAGETYPE']._serialized_end=1548
  _globals['_CHATCONTEXT']._serialized_start=1550
  _globals['_CHATCONTEXT']._serialized_end=1599
  _globals['_CHATATTACHMENTS']._serialized_start=1601
  _globals['_CHATATTACHMENTS']._serialized_end=1652
  _globals['_CREATECHATREQUEST']._serialized_start=1655
  _globals['_CREATECHATREQUEST']._serialized_end=1875
  _globals['_CREATECHATRESPONSE']._serialized_start=1877
  _globals['_CREATECHATRESPONSE']._serialized_end=1949
  _globals['_LISTCHATSREQUEST']._serialized_start=1952
  _globals['_LISTCHATSREQUEST']._serialized_end=2140
  _globals['_LISTCHATSRESPONSE']._serialized_start=2143
  _globals['_LISTCHATSRESPONSE']._serialized_end=2297
  _globals['_UPDATECHATREQUEST']._serialized_start=2300
  _globals['_UPDATECHATREQUEST']._serialized_end=2509
  _globals['_UPDATECHATRESPONSE']._serialized_start=2511
  _globals['_UPDATECHATRESPONSE']._serialized_end=2583
  _globals['_GETCHATREQUEST']._serialized_start=2585
  _globals['_GETCHATREQUEST']._serialized_end=2673
  _globals['_GETCHATRESPONSE']._serialized_start=2675
  _globals['_GETCHATRESPONSE']._serialized_end=2744
  _globals['_DELETECHATREQUEST']._serialized_start=2746
  _globals['_DELETECHATREQUEST']._serialized_end=2837
  _globals['_DELETECHATRESPONSE']._serialized_start=2839
  _globals['_DELETECHATRESPONSE']._serialized_end=2859
  _globals['_MESSAGESENDERPROFILE']._serialized_start=2862
  _globals['_MESSAGESENDERPROFILE']._serialized_end=3075
  _globals['_LISTMESSAGESREQUEST']._serialized_start=3078
  _globals['_LISTMESSAGESREQUEST']._serialized_end=3269
  _globals['_LISTMESSAGESRESPONSE']._serialized_start=3272
  _globals['_LISTMESSAGESRESPONSE']._serialized_end=3527
  _globals['_CHATWITHAGENTREQUEST']._serialized_start=3530
  _globals['_CHATWITHAGENTREQUEST']._serialized_end=3843
  _globals['_CHATWITHAGENTRESPONSE']._serialized_start=3845
  _globals['_CHATWITHAGENTRESPONSE']._serialized_end=3924
  _globals['_TABLEBUILDERAGENTMESSAGE']._serialized_start=3926
  _globals['_TABLEBUILDERAGENTMESSAGE']._serialized_end=3983
  _globals['_LISTTABLEBUILDERAGENTMESSAGESREQUEST']._serialized_start=3986
  _globals['_LISTTABLEBUILDERAGENTMESSAGESREQUEST']._serialized_end=4196
  _globals['_LISTTABLEBUILDERAGENTMESSAGESRESPONSE']._serialized_start=4199
  _globals['_LISTTABLEBUILDERAGENTMESSAGESRESPONSE']._serialized_end=4471
  _globals['_CHATWITHTABLEBUILDERAGENTREQUEST']._serialized_start=4474
  _globals['_CHATWITHTABLEBUILDERAGENTREQUEST']._serialized_end=4613
  _globals['_CHATWITHTABLEBUILDERAGENTRESPONSE']._serialized_start=4615
  _globals['_CHATWITHTABLEBUILDERAGENTRESPONSE']._serialized_end=4709
  _globals['_CHATEVENT']._serialized_start=4712
  _globals['_CHATEVENT']._serialized_end=6157
  _globals['_CHATSTARTEDEVENT']._serialized_start=6159
  _globals['_CHATSTARTEDEVENT']._serialized_end=6243
  _globals['_CHATSTATUSUPDATEDEVENT']._serialized_start=6246
  _globals['_CHATSTATUSUPDATEDEVENT']._serialized_end=6374
  _globals['_CHATOUTPUTUPDATEDEVENT']._serialized_start=6377
  _globals['_CHATOUTPUTUPDATEDEVENT']._serialized_end=6521
  _globals['_CHATNAMEUPDATEDEVENT']._serialized_start=6523
  _globals['_CHATNAMEUPDATEDEVENT']._serialized_end=6636
  _globals['_CHATREPLANTRIGGEREDEVENT']._serialized_start=6639
  _globals['_CHATREPLANTRIGGEREDEVENT']._serialized_end=6778
  _globals['_CHATCITATIONLISTUPDATEDEVENT']._serialized_start=6781
  _globals['_CHATCITATIONLISTUPDATEDEVENT']._serialized_end=6946
  _globals['_CHATATTACHMENTSUPDATEDEVENT']._serialized_start=6949
  _globals['_CHATATTACHMENTSUPDATEDEVENT']._serialized_end=7121
  _globals['_CHATCONTEXTUPDATEDEVENT']._serialized_start=7124
  _globals['_CHATCONTEXTUPDATEDEVENT']._serialized_end=7280
  _globals['_CHATTABLECREATEDEVENT']._serialized_start=7283
  _globals['_CHATTABLECREATEDEVENT']._serialized_end=7689
  _globals['_CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_start=7582
  _globals['_CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_end=7689
  _globals['_CHATTABLEUPDATEDEVENT']._serialized_start=7692
  _globals['_CHATTABLEUPDATEDEVENT']._serialized_end=8098
  _globals['_CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_start=7582
  _globals['_CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_end=7689
  _globals['_CHATERRORUPDATEDEVENT']._serialized_start=8101
  _globals['_CHATERRORUPDATEDEVENT']._serialized_end=8253
  _globals['_CHATDEBUGOUTPUTUPDATEDEVENT']._serialized_start=8256
  _globals['_CHATDEBUGOUTPUTUPDATEDEVENT']._serialized_end=8391
  _globals['_CHATENDEDEVENT']._serialized_start=8393
  _globals['_CHATENDEDEVENT']._serialized_end=8475
# @@protoc_insertion_point(module_scope)
